@@ -4,7 +4,7 @@ import yaml
 import cfnresponse
 import subprocess
 from kubernetes import client, config
-from typing import Dict
+from typing import Dict, List
 from enum import Enum
 from time import sleep, time
 
@@ -24,6 +24,10 @@ def get_aws_caller_identity():
     return boto3.client('sts').get_caller_identity()
 
 
+def get_managed_node_group_name(cluster_name: str) -> str:
+    return f"{cluster_name}-tensorkube-nodegroup"
+
+
 def generate_kubeconfig(cluster_name: str, region: str, aws_account_id: str):
     eks_client = boto3.client('eks', region_name=region)
 
@@ -142,6 +146,17 @@ def add_karpenter_role_to_aws_auth_config_map(role_arn: str):
     v1.patch_namespaced_config_map(name='aws-auth', namespace='kube-system', body=aws_auth_config_map)
 
 
+def get_availability_zones(region: str) -> List[str]:
+    ec2_client = boto3.client('ec2', region_name=region)
+    azs = ec2_client.describe_availability_zones(
+        Filters=[{"Name": "region-name", "Values": [region]}, {"Name": "zone-type", "Values": ["availability-zone"]}],
+        AllAvailabilityZones=False,
+    )["AvailabilityZones"]
+
+    zone_names = [az["ZoneName"] for az in azs if az["State"] == "available"]
+    return zone_names
+
+
 def update_values_yaml(parameters: Dict):
     cluster_name = parameters.get('ClusterName')
     sqs_access_role_arn = parameters.get('SQSAccessRoleArn')
@@ -149,6 +164,8 @@ def update_values_yaml(parameters: Dict):
     bucket_name = parameters.get('DefaultEnvBuildBucketName')
     buildkit_isra_role_arn = parameters.get('BuildkitISRARoleArn')
     job_queue_sidecar_role_arn = parameters.get('JobQueueSidecarIAMRoleArn')
+    tk_helm_charts_repo_id = parameters.get("ImageRegistryId")
+    karpenter_config_topology_zone_values = get_availability_zones(region)
 
 
     if not (cluster_name and sqs_access_role_arn and region and bucket_name and buildkit_isra_role_arn and job_queue_sidecar_role_arn):
@@ -164,7 +181,9 @@ def update_values_yaml(parameters: Dict):
     values['defaultEnvBuildBucketName'] = bucket_name
     values['buildkitISRARoleArn'] = buildkit_isra_role_arn
     values['jobQueueISRARoleArn'] = job_queue_sidecar_role_arn
-    values['managedNodeGroupName'] = f"{cluster_name}-ng-bottlerocket"
+    values['managedNodeGroupName'] = get_managed_node_group_name(cluster_name)
+    values['tkHelmChartsRepoId'] = tk_helm_charts_repo_id
+    values['karpenterConfigTopologyZoneValues'] = karpenter_config_topology_zone_values
 
     with open("/tmp/values.yaml", "w") as f:
         yaml.dump(values, f)
@@ -329,7 +348,7 @@ def wait_for_nodes_with_label_only(cluster_name: str, timeout_seconds: int = 840
 
     # Label key and value we want to keep
     label_key = "alpha.eksctl.io/nodegroup-name"
-    label_value = f"{cluster_name}-ng-bottlerocket"
+    label_value = get_managed_node_group_name(cluster_name)
 
     start_time = time()
 
