@@ -1,6 +1,6 @@
 from enum import Enum
 from typing import Optional
-
+import os
 REGION = 'us-east-1'
 NAMESPACE = 'kube-system'
 DEFAULT_NAMESPACE = 'default'
@@ -37,12 +37,16 @@ NODEPOOL = 'nodepool'
 EC2NODECLASS = 'ec2nodeclass'
 GPU_NODEPOOL_VERSION = 'gpu-v1'
 
-AWS_ACCESS_LAMBDA_FUNCTION_IMAGE_VERSION = 'v1.0.1'
-EKS_ACCESS_LAMBDA_FUNCTION_IMAGE_VERSION = 'v1.0.0'
+AWS_ACCESS_LAMBDA_FUNCTION_IMAGE_VERSION = 'v1.0.2'
+EKS_ACCESS_LAMBDA_FUNCTION_IMAGE_VERSION = 'v1.0.5'
+MONITORING_LAMBDA_FUNCTION_IMAGE_VERSION = 'v1.0.0'
 
 GPU_DEPLOYMENT_MIN_CPU = 2000
 GPU_DEPLOYMENT_MIN_MEMORY = 8000
 
+REPEATED_NOTIFICATION_PERIOD_SECONDS = "900"
+ALARM_EVALUATION_PERIODS = "45"
+
 def get_cluster_name():
     return "tensorkube"
 
@@ -62,7 +66,7 @@ def get_image_registry_id(test):
 
 
 def get_templates_version():
-    return "v0.0.2"
+    return "v0.0.9"
 
 
 def get_mount_policy_name(cluster_name: str, env: Optional[str] = None) -> str:
@@ -79,7 +83,7 @@ class Events(Enum):
     LOGGED_IN = 'logged-in'
 
     COMMAND_RUN = 'command-run'
-
+    CONFIGURED_REGION = 'configured-region'
     CONFIGURE_START = 'configure-start'
     CONFIGURE_END = 'configure-end'
     CONFIGURE_ERROR = 'configure-error'
@@ -160,6 +164,11 @@ def get_efs_security_group_name(env: Optional[str] = None) -> str:
         return f'eks-efs-sg-{get_cluster_name()}-env-{env}'
     return f'eks-efs-sg-{get_cluster_name()}'
 
-
 def get_base_login_url():
-    return 'https://api.tensorfuse.io'
+    return os.getenv("TENSORKUBE_BASE_LOGIN_URL", "https://backend.tensorfuse.io")
+
+def get_tag_for_repeated_alarm_notification() -> str:
+    return "TensorkubeRepeatedAlarm:true"
+
+def get_base_frontend_url():
+    return "https://app.tensorfuse.io"
\ No newline at end of file
