@@ -14,15 +14,17 @@ def version_to_tuple(version_str):
     return tuple(map(int, version_str.split('.')))
 
 
-def set_current_cli_version_to_cluster(context_name: Optional[str] = None):
+def set_current_cli_version_to_cluster(context_name: Optional[str] = None, version: Optional[str] = None):
     if not context_name:
         context_name = get_tensorkube_cluster_context_name()
         if not context_name:
             return None
     k8s_api_client = config.new_client_from_config(context=context_name)
     v1 = client.CoreV1Api(k8s_api_client)
+    if not version:
+        version = get_current_tensorkube_version()
     config_map = client.V1ConfigMap(metadata=client.V1ObjectMeta(name="tensorkube-migration", namespace="default"),
-                                    data={"version": get_current_tensorkube_version()})
+                                    data={"version": version})
     try:
         v1.replace_namespaced_config_map("tensorkube-migration", "default", config_map)
     except client.exceptions.ApiException as e:
@@ -56,18 +58,20 @@ def load_migrations():
     return [migration.replace('.py', '') for migration in migrations]
 
 
-def apply_migration(migration_name):
+def apply_migration(migration_name, test: bool):
     # Adjust the module path to reflect the structure starting from the project root
     migration_module_path = f"tensorkube.migration_service.migrations.{migration_name}"
     migration_module = importlib.import_module(migration_module_path)
-    migration_module.apply()
+    migration_module.apply(test=test)
 
 
-def migrate_tensorkube():
+def migrate_tensorkube(test: bool = False):
     migrations = load_migrations()
     for migration in migrations:
         click.echo(f"Applying migration {migration}...")
-        apply_migration(migration)
+        apply_migration(migration, test)
+        migration_version = ".".join(migration.split('_')[:3])
+        set_current_cli_version_to_cluster(version=migration_version)
     set_current_cli_version_to_cluster()
     click.echo("Migration completed successfully.")
     cluster_tensorkube_version = get_cluster_tensorkube_version()
