@@ -5,7 +5,7 @@ from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name,
 from tensorkube.services.knative_service import list_ksvc_in_namespace, apply_virtual_service_for_routing
 
 
-def apply():
+def apply(test: bool = False):
     # list all ksvcs across all namespaces
     # apply a virtualservice for all those ksvcs
     context_name = get_tensorkube_cluster_context_name()
