@@ -1,12 +1,12 @@
 from tensorkube.services.job_queue_service import create_cloud_resources_for_queued_job_support
-from tensorkube.services.aws_service import get_bucket_name, get_credentials
-from tensorkube.services.s3_service import create_s3_bucket
+from tensorkube.services.aws_service import get_credentials
+from tensorkube.services.s3_service import create_s3_bucket, get_bucket_name
 from tensorkube.services.k8s_service import create_aws_secret
 from tensorkube.constants import get_cluster_name
 from tensorkube.services.iam_service import attach_role_policy, get_aws_account_id
 import click
 
-def apply():
+def apply(test: bool = False):
     try:
         bucket_name = get_bucket_name(env_name='keda', type='train')
         create_s3_bucket(bucket_name)
