@@ -1,7 +1,7 @@
 from tensorkube.services.s3_access_service import create_s3_access_to_pods
 import click
 
-def apply():
+def apply(test: bool = False):
     try:
         create_s3_access_to_pods()
     except Exception as e:
