@@ -4,7 +4,7 @@ from tensorkube.services.nodepool import get_gpu_nodepool
 from tensorkube.services.nydus import install_nydus_snapshotter_helm
 import click
 
-def apply():
+def apply(test: bool = False):
     try:
         install_istio_on_cluster()
         click.echo("Successfully increased connection idle timeout")
