@@ -1,7 +1,7 @@
 from tensorkube.services.istio import install_istio_on_cluster
 import click
 
-def apply():
+def apply(test: bool = False):
     try:
         install_istio_on_cluster()
         click.echo("Successfully increased connection idle timeout")
