@@ -8,7 +8,7 @@ from kubernetes import config, client
 
 from tensorkube.constants import get_cluster_name, NAMESPACE, DEFAULT_NAMESPACE, KNATIVE_SERVING_NAMESPACE, \
     CONFIG_FEATURES, ADDON_NAME, get_mount_driver_role_name
-from tensorkube.services.aws_service import get_bucket_name, get_aws_account_id
+from tensorkube.services.aws_service import get_aws_account_id
 from tensorkube.services.eks_service import install_karpenter, delete_eks_addon, create_eks_addon
 from tensorkube.services.eksctl_service import delete_nodegroup
 from tensorkube.services.filesystem_service import configure_efs, cleanup_filesystem_resources
@@ -17,9 +17,10 @@ from tensorkube.services.k8s_service import check_nodes_ready, evict_pods_from_n
     check_pvc_exists_by_name, get_tensorkube_cluster_context_name
 from tensorkube.services.karpenter_service import update_ec2_node_class_ami
 from tensorkube.services.logging_service import configure_cloudwatch
+from tensorkube.services.s3_service import get_bucket_name
 
 
-def create_and_wait_for_nodegroup():
+def create_and_wait_for_nodegroup(test: bool = False):
     cluster_name = get_cluster_name()
     nodegroup_name = f"{cluster_name}-ng-bottlerocket"
     # Access the YAML file using importlib.resources
