@@ -3,50 +3,130 @@ import platform
 import shutil
 import subprocess
 import uuid
-from typing import Optional
+from typing import Optional, List
 
 import boto3
 import botocore
 import click
 import semver
 
-from tensorkube.constants import CliColors, REGION
+from tensorkube.constants import CliColors
 from tensorkube.constants import get_cluster_name, DEFAULT_NAMESPACE, LOCKED_AWS_CLI_VERSION
 from tensorkube.services.error import CLIVersionError
-from tensorkube.services.s3_service import list_s3_buckets
-
-
-def get_session_region():
-    return boto3.session.Session().region_name
+import configparser
 
+TENSORFUSE_SESSION = 'tensorfuse'
 
 def get_eks_client():
-    return boto3.client("eks")
+    session = get_boto3_session()
+    return session.client("eks")
 
+def get_session_region():
+    session  = get_boto3_session()
+    return session.region_name
 
 def get_cloudformation_client():
-    return boto3.client("cloudformation")
+    session = get_boto3_session()
+    return session.client("cloudformation")
 
 
 def get_ec2_client():
-    return boto3.client("ec2")
+    session = get_boto3_session()
+    return session.client("ec2")
 
 
 def get_iam_client():
-    return boto3.client("iam")
+    session = get_boto3_session()
+    return session.client("iam")
+
+def get_sts_client():
+    session = get_boto3_session()
+    return session.client("sts")
+
+def get_s3_client():
+    session = get_boto3_session()
+    return session.client("s3")
+
+def get_s3_resource():
+    session = get_boto3_session()
+    return session.resource("s3")
+
+def get_ecr_client():
+    session = get_boto3_session()
+    return session.client("ecr")
+
+def get_efs_client():
+    session = get_boto3_session()
+    return session.client("efs")
 
 
 def get_aws_account_id():
-    sts = boto3.client('sts')
+    sts = get_sts_client()
     identity = sts.get_caller_identity()
     return identity['Account']
 
+def get_logs_client():
+    session = get_boto3_session()
+    return session.client("logs")
+
+def get_sqs_client():
+    session = get_boto3_session()
+    return session.client("sqs")
+
+def get_dynamodb_client():
+    session = get_boto3_session()
+    return session.client("dynamodb")
+
+def get_dynamodb_resource():
+    session = get_boto3_session()
+    return session.resource("dynamodb")
 
 def get_aws_user_arn() -> str:
-    sts = boto3.client('sts')
+    session = get_boto3_session()
+    sts = session.client('sts')
     identity = sts.get_caller_identity()
     return identity['Arn']
 
+def get_boto3_session():
+    default_session = boto3.Session()
+    config_path = os.path.expanduser(
+        os.environ.get("AWS_CONFIG_FILE", "~/.aws/config")
+    )
+
+    if not default_session.available_profiles and os.environ.get("AWS_DEFAULT_REGION") is None:
+        raise click.ClickException("No AWS profiles found. Please configure your AWS profile using the command: `aws configure sso`")
+        
+    if TENSORFUSE_SESSION in default_session.available_profiles:
+        if not os.path.isfile(config_path):
+            text =  f"AWS config file not found at {config_path}; using default session"
+            click.echo(click.style(text, bold=True, fg=CliColors.WARNING.value))
+            return default_session
+
+        # load and parse
+        cfg = configparser.ConfigParser()
+        try:
+            cfg.read(config_path)
+        except Exception as e:
+            text = f"Failed to read AWS config file ({e}); using default session"
+            click.echo(click.style(text, bold=True, fg=CliColors.WARNING.value))
+            return default_session
+
+        profile_section = f"profile {TENSORFUSE_SESSION}"
+        try:
+            region = cfg.get(profile_section, "region")
+        except (configparser.NoSectionError, configparser.NoOptionError) as e:
+            text = f"Profile or region not found in config ({e}); using default session"
+            click.echo(click.style(text, bold=True, fg=CliColors.WARNING.value))
+            return default_session
+
+        # if we got a region, build a session with it
+        if region:
+            return boto3.Session(profile_name=TENSORFUSE_SESSION, region_name=region)
+    return default_session
+
+def get_session_profile_name():
+    session = get_boto3_session()
+    return session.profile_name
 
 def get_principal_arn_from_identity_center_arn(arn: str) -> str:
     arn_parts = arn.split(':')
@@ -57,7 +137,7 @@ def get_principal_arn_from_identity_center_arn(arn: str) -> str:
 
 
 def get_aws_user_principal_arn() -> str:
-    sts = boto3.client('sts')
+    sts = get_sts_client()
     identity = sts.get_caller_identity()
     if 'assumed-role' in identity['Arn']:
         return get_principal_arn_from_identity_center_arn(identity['Arn'])
@@ -72,20 +152,14 @@ def get_karpenter_version():
     return "0.37.0"
 
 
-def get_aws_default_region():
-    return "us-east-1"
-
-
-def get_kubernetes_context_name():
-    return f"{get_cluster_name()}.{get_aws_default_region()}.eksctl.io"
-
-
 def get_credentials():
-    return boto3.Session().get_credentials().get_frozen_credentials()
+    session =  get_boto3_session()
+    return session.get_credentials().get_frozen_credentials()
 
 
 def are_credentials_valid(credentials):
-    sts = boto3.client('sts', aws_access_key_id=credentials.access_key, aws_secret_access_key=credentials.secret_key,
+    session = get_boto3_session()
+    sts = session.client('sts', aws_access_key_id=credentials.access_key, aws_secret_access_key=credentials.secret_key,
                        aws_session_token=credentials.token)
     try:
         sts.get_caller_identity()
@@ -94,37 +168,6 @@ def are_credentials_valid(credentials):
         return False
 
 
-# TODO!: make function generic to get any config value
-def get_bucket_name(env_name: Optional[str] = None, type: str = "build"):
-    buckets = list_s3_buckets()
-    if env_name and env_name != DEFAULT_NAMESPACE:
-        prefix = f'{get_cluster_name()}-{env_name}-{type}-bucket-'
-    else:
-        prefix = f'{get_cluster_name()}-{type}-bucket-'
-    # checks if such a bucket already exists
-    for bucket in buckets:
-        if bucket['Name'].startswith(prefix):
-            return bucket['Name']
-    else:
-        bucket_name = f"{prefix}{str(uuid.uuid4())[:18]}"
-        if len(bucket_name) > 63:
-            raise ValueError("Environment name is too long. Please use a shorter name.")
-        return bucket_name
-
-
-def get_existing_bucket_name(env_name: Optional[str] = None, type: str = "build"):
-    buckets = list_s3_buckets()
-    if env_name and env_name != DEFAULT_NAMESPACE:
-        prefix = f'{get_cluster_name()}-{env_name}-{type}-bucket-'
-    else:
-        prefix = f'{get_cluster_name()}-{type}-bucket-'
-    # checks if such a bucket already exists
-    for bucket in buckets:
-        if bucket['Name'].startswith(prefix):
-            return bucket['Name']
-
-    return None
-
 
 def check_and_install_aws_cli():
     """Check if aws cli is installed and if not install it."""
@@ -202,7 +245,19 @@ zoneIDsToAvoid = {
 }
 
 
-def get_eks_control_plane_available_zones_for_region(region:str=REGION):
-    ec2 = boto3.client('ec2', region_name=region)
+def get_eks_control_plane_available_zones_for_region():
+    ec2 = get_ec2_client()
+    region = get_session_region()
     response = ec2.describe_availability_zones()
     return [zone['ZoneName'] for zone in response['AvailabilityZones'] if zone['ZoneId'] not in zoneIDsToAvoid.get(region, []) and zone['ZoneType'] == "availability-zone"]
+
+
+def get_availability_zones(region: str) -> List[str]:
+    ec2_client = boto3.client('ec2', region_name=region)
+    azs = ec2_client.describe_availability_zones(
+        Filters=[{"Name": "region-name", "Values": [region]}, {"Name": "zone-type", "Values": ["availability-zone"]}],
+        AllAvailabilityZones=False,
+    )["AvailabilityZones"]
+
+    zone_names = [az["ZoneName"] for az in azs if az["State"] == "available"]
+    return zone_names
