@@ -1,6 +1,6 @@
 from typing import Optional, List
-from tensorkube.constants import REGION, DEFAULT_NAMESPACE, get_cluster_name
-from tensorkube.services.aws_service import get_aws_account_id
+from tensorkube.constants import DEFAULT_NAMESPACE, get_cluster_name
+from tensorkube.services.aws_service import get_aws_account_id, get_session_region
 from tensorkube.services.nydus import get_nydus_image_url
 from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name, get_s3_claim_name, get_efs_claim_name
 from pkg_resources import resource_filename
@@ -11,7 +11,11 @@ from tensorkube.services.iam_service import create_or_update_iam_role_with_servi
 from tensorkube.services.eks_service import get_cluster_oidc_issuer_url
 from tensorkube.services.k8s_service import patch_service_account, create_service_account
 
-def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url: Optional[str] =None, upload_to_nfs: bool= False, region: str = REGION, convert_to_nydus_image: bool = False, secrets: List[str] = []):
+    
+def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url: Optional[str] =None,
+                         upload_to_nfs: bool= False, convert_to_nydus_image: bool = False, secrets: List[str] = [],
+                         relative_dockerfile_path: str = "Dockerfile"):
+    region = get_session_region()
     aws_account_number =  get_aws_account_id()
     secrets_to_env_vars_command = ""
     if secrets:
@@ -28,6 +32,7 @@ def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url:
                         env_vars="$env_vars --secret id=$filename,src=$folder_path/$filename"
                     fi
                 done"""
+    # Ensure dockerfile local is mounted and filename is relative to that root
     command = [ "/bin/sh", "-c",
         f"""
         apk add --no-cache curl unzip aws-cli docker
@@ -37,6 +42,7 @@ def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url:
             --frontend dockerfile.v0\
             --local context=/data/build/{sanitised_project_name}\
             --local dockerfile=/data/build/{sanitised_project_name}\
+            --opt filename={relative_dockerfile_path}\
             --output type=image,name={image_url},push=true \
             $env_vars
         """
@@ -52,6 +58,7 @@ def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url:
                 --frontend dockerfile.v0\
                 --local context=/data/build/{sanitised_project_name}\
                 --local dockerfile=/data/build/{sanitised_project_name}\
+                --opt filename={relative_dockerfile_path}\
                 --output type=image,name={nydus_image_url},push=true,compression=nydus,force-compression=true,oci-mediatypes=true \
                 $env_vars
             """
@@ -67,6 +74,7 @@ def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url:
             --frontend dockerfile.v0\
             --local context=/data/build/{sanitised_project_name}\
             --local dockerfile=/data/build/{sanitised_project_name}\
+            --opt filename={relative_dockerfile_path}\
             --output type=tar,dest=/test/tars/{sanitised_project_name}/{sanitised_project_name}-{image_tag}.tar \
             $env_vars
         if [ $? -ne 0 ]; then
@@ -123,8 +131,11 @@ def get_buildkit_command(sanitised_project_name: str, image_tag: str, image_url:
     return command
 
 
-def apply_k8s_buildkit_config(sanitised_project_name: str, image_tag: str, region: str = REGION,
-                              env_name: Optional[str] = None, context_name: Optional[str] = None, image_url: Optional[str] = None, upload_to_nfs: bool = False,convert_to_nydus_image: bool = False, secrets: List[str] = []):
+def apply_k8s_buildkit_config(sanitised_project_name: str, image_tag: str,
+                              env_name: Optional[str] = None, context_name: Optional[str] = None,
+                              image_url: Optional[str] = None, upload_to_nfs: bool = False,
+                              convert_to_nydus_image: bool = False, secrets: List[str] = [],
+                              relative_dockerfile_path: str = "Dockerfile"):
     if not context_name:
         context_name = get_tensorkube_cluster_context_name()
         if not context_name:
@@ -136,7 +147,7 @@ def apply_k8s_buildkit_config(sanitised_project_name: str, image_tag: str, regio
         buildkit_config = yaml.safe_load(f)
 
     buildkit_config['metadata']['name'] = 'buildkit-{}'.format(sanitised_project_name)
-    buildkit_config['spec']['template']['spec']['containers'][0]['env'][0]['value'] = region
+    buildkit_config['spec']['template']['spec']['containers'][0]['env'][0]['value'] = get_session_region()
     buildkit_config['spec']['ttlSecondsAfterFinished'] = 100
     
 
@@ -172,7 +183,9 @@ def apply_k8s_buildkit_config(sanitised_project_name: str, image_tag: str, regio
         elif volume['name'] == 'efs-pvc':
             volume['persistentVolumeClaim']['claimName'] = get_efs_claim_name(env_name=env_name)
 
-    buildkit_config['spec']['template']['spec']['containers'][0]['command'] = get_buildkit_command(sanitised_project_name, image_tag, image_url, upload_to_nfs, region, convert_to_nydus_image, secrets)
+    buildkit_config['spec']['template']['spec']['containers'][0]['command'] = get_buildkit_command(
+        sanitised_project_name, image_tag, image_url, upload_to_nfs, convert_to_nydus_image, secrets,
+        relative_dockerfile_path=relative_dockerfile_path)
 
     utils.create_from_dict(k8s_api_client, buildkit_config)
     click.echo('Deployed a Buildkit image')
@@ -185,7 +198,7 @@ def configure_buildkit_irsa(env_name: Optional[str] = None):
     role_name = get_buildkit_ecr_iam_role_name()
     role = create_or_update_iam_role_with_service_account_cluster_access(get_aws_account_id(),get_cluster_oidc_issuer_url(get_cluster_name()), role_name, service_account_name, namespace)
     role_arn = role["Role"]["Arn"]
-    attach_role_policy("aws", "AmazonEC2ContainerRegistryPowerUser", role_name, REGION)
+    attach_role_policy("aws", "AmazonEC2ContainerRegistryPowerUser", role_name)
     patch_service_account(role_arn, service_account_name, namespace)
 
 def get_buildkit_service_account_name(namespace: str):
