@@ -1,27 +1,31 @@
+import os.path
 import time
 from datetime import datetime, timezone
 import sys
 import importlib.metadata
-
 import click
 
 from tensorkube.constants import REGION, Events, DEFAULT_NAMESPACE, get_cluster_name, CliColors, \
-    get_cfn_base_stack_name, TeardownType
-from tensorkube.constants import get_base_login_url
-from tensorkube.helpers import sanitise_assumed_role_arn, track_event, sanitise_name
+    get_cfn_base_stack_name, TeardownType, get_base_login_url, get_base_frontend_url
+
+from tensorkube.helpers import sanitise_assumed_role_arn, track_event, sanitise_name, is_valid_email, create_user_access_entry, verify_user
 from tensorkube.migration_service.migration_manager.migration_service import migrate_tensorkube
+
 from tensorkube.services.aws_service import get_aws_account_id, get_aws_user_arn, \
-    get_aws_user_principal_arn, get_session_region, check_and_install_aws_cli, get_existing_bucket_name
+    get_aws_user_principal_arn, get_session_region, check_and_install_aws_cli, get_session_profile_name
 from tensorkube.services.cloudformation_service import get_validation_records_from_events, \
-    get_validation_records_with_wait, get_stack_status_from_stack_name, determine_teardown_type, CfnStackStatus
+    get_validation_records_with_wait, get_stack_status_from_stack_name, determine_teardown_type, CfnStackStatus, \
+    stream_stack_events
 from tensorkube.services.configure_service import legacy_configure, cfn_configure
 from tensorkube.services.dataset_service import upload_tensorkube_dataset, delete_tensorkube_dataset
 from tensorkube.services.deploy import deploy_knative_service, DEFAULT_GPUS, DEFAULT_CPU, DEFAULT_MEMORY, \
-    DEFAULT_MIN_SCALE, DEFAULT_MAX_SCALE, DEFAULT_ENV, DEFAULT_SECRET, build_app, create_deployment_details
+    DEFAULT_MIN_SCALE, DEFAULT_MAX_SCALE, DEFAULT_ENV, DEFAULT_SECRET, build_app, create_deployment_details, \
+    DEFAULT_GITHUB_ACTIONS, DEFAULT_DOMAIN_NAME, DEFAULT_GPU_TYPE, DEFAULT_ENTRYPOINT, DEFAULT_BUILD_CONTEXT, \
+    get_cwd_and_sanitised_project_name, MAX_DEPLOYMENT_NAME_LENGTH
 from tensorkube.services.deploy_config_service import Config, run_deployment_config_pre_flight_checks
 from tensorkube.services.dynamodb_service import get_all_job_statuses, get_job_statuses
 from tensorkube.services.ecr_service import delete_all_tensorkube_ecr_repositories
-from tensorkube.services.eks_service import update_eks_kubeconfig, give_eks_cluster_access
+from tensorkube.services.eks_service import update_eks_kubeconfig, give_eks_cluster_access, is_existing_access_entry
 
 from tensorkube.services.environment_service import create_new_environment, list_environments, delete_environment
 from tensorkube.services.filesystem_service import create_efs_volume_for_cluster_cfn, \
@@ -33,17 +37,18 @@ from tensorkube.services.iam_service import create_iam_user, create_eks_access_p
 from tensorkube.services.job_queue_service import deploy_job, queue_job, get_job_status, delete_all_job_resources, \
     is_existing_queued_job
 from tensorkube.services.k8s_service import create_secret, list_secrets, delete_secret, list_keda_scaled_jobs, \
-    add_user_to_k8s
+    add_user_to_k8s, get_pod_name_corresponing_to_job
 from tensorkube.services.kubectl_utils import check_and_install_helm, check_and_install_kubectl
 from tensorkube.services.local_service import check_and_install_cli_tools
 from tensorkube.services.metapod_service import list_instances_in_cloud, start_devcontainer, purge_devcontainer, \
     pause_devcontainer, reset_cloud
+from tensorkube.services.one_shot_job_service import deploy_one_shot_job, DEFAULT_FOLLOW
 from tensorkube.services.rich_service import list_tensorkube_deployments, describe_deployment, display_deployment_logs, \
     ssh_into_deployed_service, display_secrets, list_tensorkube_datasets, display_job_logs, \
     delete_tensorkube_job_by_prefix, list_tensorkube_training_jobs, display_queued_jobs, get_tensorkube_training_job, \
     prettify_aws_user_keys, display_specific_queued_job, display_dns_records_table, delete_deployment, \
     display_efs_volumes
-from tensorkube.services.teardown_service import legacy_teardown, cfn_teardown
+from tensorkube.services.teardown_service import legacy_teardown, cfn_teardown, start_remote_teardown
 from tensorkube.services.tls_service import configure_certificate, get_certificate_stack_name, attach_domain_name, \
     validate_domain, check_if_a_domain_is_validated
 from tensorkube.services.train import axolotl_train, get_job_prefix_from_job_id
@@ -52,6 +57,8 @@ from tensorkube.tensorkube_token_server import run_server
 from tensorkube.services.nydus import get_nydus_image_url
 from tensorkube.services.ecr_service import get_or_create_ecr_repository
 from tensorkube.services.version_service import print_tensorkube_version
+from tensorkube.services.teardown_service import legacy_teardown, cfn_teardown
+from tensorkube.services.s3_service import get_existing_bucket_name, delete_s3_bucket
 
 
 @click.group()
@@ -122,12 +129,13 @@ def install_prerequisites():
 
 
 @tensorkube.command()
-def upgrade():
+@click.option('--test', is_flag=True, help='Migrate using test configurations.')
+def upgrade(test):
     """Migrate your tensorfuse cluster to the latest version of tensorkube.
 
     This command automatically takes all the necessary actions to upgrade the software that is  managing your Tensorfuse cluster.
     """
-    migrate_tensorkube()
+    migrate_tensorkube(test)
 
 
 @tensorkube.command()
@@ -139,102 +147,11 @@ def upgrade():
 def configure(vpc_public_subnets, vpc_private_subnets, legacy, test, override_policy_checks):
     """Configure the Tensorkube runtime on your private cloud
     """
-    click.echo("Configuring the Tensorfuse runtime for your cloud...")
-    start_time = time.time() * 1000
-    can_track = track_event(Events.CONFIGURE_START.value, {"start_time": start_time})
-    if not can_track:
-        click.echo("You need to login to Tensorfuse to configure Tensorkube.")
-        click.echo("Please login using the command: " + click.style("tensorkube login", fg='cyan'))
-        return
+    track_event(Events.CONFIGURE_START.value, {})
+    click.echo("We have moved configure from the CLI to our web app for a better user experience. Please visit " + click.style("https://app.tensorfuse.io/", fg='cyan', bold=True) + " to configure your cluster. \n🚀 Happy configuring!")
+    return
 
 
-    if vpc_public_subnets and vpc_private_subnets:
-        if not legacy:
-            info_text = click.style("Configuring Tensorkube with existing VPCs is not supported in this version of configure. Please use the --legacy flag to use the legacy configuration.", fg=CliColors.WARNING.value)
-            click.echo(info_text)
-
-            end_time = time.time() * 1000
-            track_event(Events.CONFIGURE_END.value,
-                        {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "vpc_not_supported"})
-            return
-    confirmation_txt = click.style("Confirmation: Tensorfuse sets up resources such as a Kubernetes cluster, load balancer, and cluster autoscaler to enable serverless GPUs and features like job queues. The estimated base cost for this setup is approximately ") + click.style("$300 per month", bold=True) + click.style(", billed by AWS. Please select \"Yes\" if you wish to proceed.")
-    confirmation = click.confirm(confirmation_txt, default=False)
-    if not confirmation:
-        end_time = time.time() * 1000
-        track_event(Events.CONFIGURE_END.value,
-                {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "confirmation_declined"})
-        return
-    session_region = get_session_region()
-    if session_region != REGION:
-        end_time = time.time() * 1000
-        track_event(Events.CONFIGURE_END.value,
-                {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "region_not_supported", "region": session_region})
-        click.echo(click.style( f"Error: The current region is {session_region}. Tensorfuse currently supports only {REGION} region. Either switch your region to {REGION} or reach out to ", bold=True,
-                        fg=CliColors.ERROR.value) + click.style( "founders@tensorfuse.io", italic=True, bold=True, fg=CliColors.ERROR.value) + click.style(" for support.", bold=True, fg=CliColors.ERROR.value))
-        return
-
-    if override_policy_checks:
-        has_permissions = True
-        click.echo(click.style("You are overriding permissions and policy checks. You may run into permission issues", bold=True, fg=CliColors.WARNING.value))
-    else:
-        has_permissions = has_configure_permissions()
-    if not has_permissions:
-        end_time = time.time() * 1000
-        click.echo("Insufficient AWS permissions to run the configure command. Please contact your AWS admin.")
-        track_event(Events.CONFIGURE_END.value,
-                {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "insufficient_permissions"})
-        return
-
-    click.echo("All permissions are in place. Starting configure...")
-    if legacy:
-        try:
-            success = legacy_configure(vpc_public_subnets, vpc_private_subnets)
-            if not success:
-                return
-
-            end_time = time.time() * 1000
-            track_event(Events.CONFIGURE_END.value,
-                        {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
-            click.echo("Your tensorfuse cluster is ready and you are good to go.")
-        except Exception as e:
-            #TODO: add exception handling for ctrl+c
-            click.echo(f"Error while configuring Tensorfuse: {e}")
-            end_time = time.time() * 1000
-            track_event(Events.CONFIGURE_END.value,
-                        {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "error"})
-            return
-    else:
-        try:
-            check_and_install_aws_cli()
-            check_and_install_kubectl()
-            check_and_install_helm()
-
-            cfn_configure(test)
-
-            status = get_stack_status_from_stack_name(get_cfn_base_stack_name())
-            if status != CfnStackStatus.CREATE_COMPLETE:
-                click.echo(f"Error while configuring Tensorfuse. Please check the cloudformation stack [{get_cfn_base_stack_name()}] for more details.")
-                end_time = time.time() * 1000
-                track_event(Events.CONFIGURE_ERROR.value,
-                            {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "error"})
-                return
-
-            click.echo("Syncing config files for the tensorkube cluster...")
-            click.echo("Updating kubeconfig...")
-            update_eks_kubeconfig()
-            click.echo("Successfully updated the kubeconfig file.")
-
-            end_time = time.time() * 1000
-            track_event(Events.CONFIGURE_END.value,
-                        {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
-            click.echo("Your tensorfuse cluster is ready and you are good to go!")
-        except Exception as e:
-            click.echo("Error while configuring Tensorfuse. {}".format(e))
-            end_time = time.time() * 1000
-            track_event(Events.CONFIGURE_END.value,
-                        {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time, "status": "error"})
-            return
-
 
 @tensorkube.command()
 def account():
@@ -256,7 +173,9 @@ def cluster():
 # delete cluster
 
 @tensorkube.command()
-def teardown():
+@click.option("--purge", is_flag=True, help="Flag to purge all training datasets and buckets. Highly destructive action. Use with caution.")
+@click.option("--remote", is_flag=True, help="Flag to request a remote teardown. This will not run the teardown locally but will request the remote server to run the teardown.")
+def teardown(purge, remote):
     """
     HIGHLY DESTRUCTIVE ACTION!!!! Don't run this command if you don't intend to delete all the resources that you have created and configured using the CLI.
 
@@ -303,17 +222,36 @@ def teardown():
         click.echo("Identified configure. Starting teardown...")
         train_bucket_name = get_existing_bucket_name("keda", "train")
         if train_bucket_name:
-            click.echo(click.style(f"You train bucket, ", fg=CliColors.WARNING.value) +
-                       click.style(train_bucket_name, fg=CliColors.WARNING.value, bold=True, italic=True) +
-                       click.style(" will not be deleted as it might contain your models.", fg=CliColors.WARNING.value)
-                       )
-            click.echo(click.style("If you wish to delete the bucket, you must do so manually using the AWS console or using the following command:", fg=CliColors.WARNING.value))
-            click.echo(click.style(f"aws s3 rb s3://{train_bucket_name}", italic=True, fg=CliColors.WARNING.value))
-            click.echo(click.style("Use the ", fg=CliColors.WARNING.value)+
-                       click.style("--force", italic=True, fg=CliColors.WARNING.value)+
-                       click.style(" flag to delete any non-versioned objects in the bucket", fg=CliColors.WARNING.value)
-                       )
-            click.echo(click.style("Note: You will not be able to re-configure tensorkube unless you delete this bucket", bold=True, fg=CliColors.ERROR.value))
+            if purge:
+                click.echo("Purging all training datasets and buckets...")
+                delete_s3_bucket(train_bucket_name)
+            else:
+                click.echo(click.style(f"You train bucket, ", fg=CliColors.WARNING.value) +
+                           click.style(train_bucket_name, fg=CliColors.WARNING.value, bold=True, italic=True) +
+                           click.style(" will not be deleted as it might contain your models.", fg=CliColors.WARNING.value)
+                           )
+                click.echo(click.style("If you wish to delete the bucket, you must do so manually using the AWS console or using the following command:", fg=CliColors.WARNING.value))
+                click.echo(click.style(f"aws s3 rb s3://{train_bucket_name}", italic=True, fg=CliColors.WARNING.value))
+                click.echo(click.style("Use the ", fg=CliColors.WARNING.value)+
+                           click.style("--force", italic=True, fg=CliColors.WARNING.value)+
+                           click.style(" flag to delete any non-versioned objects in the bucket", fg=CliColors.WARNING.value)
+                           )
+                click.echo(click.style("Note: You will not be able to re-configure tensorkube unless you delete this bucket", bold=True, fg=CliColors.ERROR.value))
+
+        if remote:
+            success = start_remote_teardown()
+            end_time = time.time() * 1000
+            if success:
+                track_event(Events.TEARDOWN_END.value,
+                            {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
+                click.echo("Teardown started. Tensorfuse will be successfully disconnected from your account.")
+                stream_stack_events(get_cfn_base_stack_name())
+                return
+            else:
+                track_event(Events.TEARDOWN_END.value,
+                            {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
+                click.echo("Error while starting remote teardown. Please try again later or contact support.")
+                return
 
         cfn_teardown()
 
@@ -357,7 +295,10 @@ def teardown():
               help='Path to the config.yaml file. you can use this file instead of cli flags. Keys in config.yaml take precedence than cli flags.')
 @click.option('--domain-name', type=str, default=None, help='Domain to use for the deployment.')
 @click.option('--port', type=int, default=80, help='Port to expose the service on.')
-def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_actions, secret, efs, concurrency, config_file, domain_name, port):
+@click.option('--build-context', type=str, default=DEFAULT_BUILD_CONTEXT, help='Path to the build context. Defaults to current directory.')
+@click.option('--dockerfile', type=str, default=f"{DEFAULT_BUILD_CONTEXT}/Dockerfile", help='Path to Dockerfile. Defaults to ./Dockerfile')
+def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_actions, secret, efs, concurrency,
+           config_file, domain_name, port, build_context, dockerfile):
     """
     Deploy your containerized application on Tensorkube. This command requires
     a dockerfile to be present in the current directory.
@@ -371,7 +312,9 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
         click.echo(f"Failed to read config.yaml file: {e}")
         return
 
-    config.set_if_not_exist('gpus', gpus)\
+    working_dir, sanitised_project_name = get_cwd_and_sanitised_project_name(build_context=build_context)
+
+    config.set_if_not_exist('gpus', gpus) \
         .set_if_not_exist('gpu_type', gpu_type)\
         .set_if_not_exist('cpu', cpu)\
         .set_if_not_exist('memory', memory)\
@@ -385,6 +328,18 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
         .set_if_not_exist('concurrency', concurrency)\
         .set_if_not_exist('port', port)
 
+    # if Dockerfile dir and build context dir are different, then deployment name should be explicitly specified
+    build_context_abs = os.path.abspath(build_context)
+    dockerfile_abs = os.path.abspath(dockerfile)
+    if os.path.dirname(dockerfile_abs) != build_context_abs and not config.get('name'):
+        click.echo(click.style("Error: When Dockerfile directory and build context directory are different, you must explicitly specify a deployment name using the 'name' field in config.yaml.", fg=CliColors.ERROR.value))
+        return
+
+    config.set_if_not_exist('name', sanitised_project_name)
+    if len(config.get('name')) > MAX_DEPLOYMENT_NAME_LENGTH:
+        config.update('name', config.get('name')[:MAX_DEPLOYMENT_NAME_LENGTH].rstrip('-'))
+        click.echo(click.style(f"WARNING: Deployment name is too long. It has been truncated to {config.get('name')} ({MAX_DEPLOYMENT_NAME_LENGTH} characters). Please use the `name` parameter in the config.yaml file to set a name within the character limit", fg=CliColors.WARNING.value))
+
     # flags validation
     if config.get('gpus') > 0:
         if not config.get('gpu_type'):
@@ -410,18 +365,13 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
         click.echo('Error: Invalid number of GPUs. Only supported values are 0, 1, 4, and 8.')
         return
     click.echo(click.style("Preparing image details", fg=CliColors.INFO.value))
-    depl_secrets, env_namespace, image_tag, cwd, sanitised_project_name = create_deployment_details(secret=config.get('secret'),
+    depl_secrets, env_namespace, image_tag = create_deployment_details(secret=config.get('secret'),
                                                                                                   env=config.get('env'))
     if not image_tag:
         return
     enable_efs = False
     if config.get('efs'):
         enable_efs = True
-    repo_url = get_or_create_ecr_repository(sanitised_project_name)
-    image_url = f"{repo_url}:{image_tag}"
-    
-    convert_to_nydus_image = True  if config.get('gpus') > 0 and not enable_efs else False
-    click.echo(click.style("Starting the build process...", fg=CliColors.INFO.value))
 
     click.echo("Running pre-flight checks...")
     checks_successful = run_deployment_config_pre_flight_checks(config)
@@ -429,9 +379,15 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
         click.echo("Deployment checks failed. Please check the logs for more details.")
         return
 
+    repo_url = get_or_create_ecr_repository(config.get('name'))
+    image_url = f"{repo_url}:{image_tag}"
+    
+    convert_to_nydus_image = True  if config.get('gpus') > 0 and not enable_efs else False
+    click.echo(click.style("Starting the build process...", fg=CliColors.INFO.value))
 
-    pod_status = build_app(env=config.get('env'), image_tag=image_tag, sanitised_project_name=sanitised_project_name,
-                           upload_to_nfs=enable_efs, image_url=image_url, convert_to_nydus_image=convert_to_nydus_image, secrets=config.get('secret'))
+    pod_status = build_app(env=config.get('env'), image_tag=image_tag, sanitised_project_name=config.get('name'),
+                           upload_to_nfs=enable_efs, image_url=image_url, convert_to_nydus_image=convert_to_nydus_image,
+                           secrets=config.get('secret'), work_dir=build_context, dockerfile=dockerfile)
     if config.get('gpus') > 0:
         image_url = get_nydus_image_url(image_url=image_url)
     if enable_efs:
@@ -439,8 +395,8 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
     deploy_knative_service(env=config.get('env'), gpus=config.get('gpus'),
                            gpu_type=config.get('gpu_type'), cpu=config.get('cpu'), memory=config.get('memory'),
                            min_scale=config.get('min_scale'), max_scale=config.get('max_scale'),
-                           concurrency= config.get('concurrency'), pod_status=pod_status, cwd=cwd,
-                           sanitised_project_name=sanitised_project_name, image_url=image_url, secrets=depl_secrets,
+                           concurrency= config.get('concurrency'), pod_status=pod_status, dockerfile=dockerfile,
+                           sanitised_project_name=config.get('name'), image_url=image_url, secrets=depl_secrets,
                            enable_efs=enable_efs, domain=config.get('domain_name'), github_actions=config.get('github_actions'),
                            startup_probe = config.get('startup_probe'), liveness_probe = config.get('liveness'),
                            readiness = config.get('readiness'), port = config.get('port'), volumes=config.get('volumes'))
@@ -448,6 +404,9 @@ def deploy(gpus, gpu_type, cpu, memory, min_scale, max_scale, env, github_action
     end_time = time.time() * 1000
     track_event(Events.DEPLOY_END.value,
                 {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
+    
+    #TODO Verify this url
+    click.echo("Now you can access your deployment at: " + click.style(f"{get_base_frontend_url()}/deployments/", fg='cyan'))
 
 
 
@@ -477,19 +436,45 @@ def get_permissions_command():
     --region {} \\
     --arn {} \\
     --group system:masters \\
-    --username <USERNAME_OF_YOUR_CHOICE>""".format(get_cluster_name(), REGION, final_arn))
+    --username <USERNAME_OF_YOUR_CHOICE>""".format(get_cluster_name(), get_session_region(), final_arn))
 
     click.echo("Once you have access to the cluster, run the following command to sync the config files:")
     click.echo("tensorkube sync")
 
-
+# TODO: VERIFY THE PROFILE THING
 @tensorkube.command()
 def sync():
     """Sync the Tensorfuse configuration on a new machine.
     """
     click.echo("Syncing config files for the tensorkube cluster...")
     click.echo("Updating kubeconfig...")
-    update_eks_kubeconfig()
+    
+    #TODO use track event
+    user_email, region = verify_user()
+    if not user_email:
+        click.echo("You need to login to Tensorfuse to run your deployment.")
+        click.echo("Please login using the command: " + click.style("tensorkube login", fg='cyan'))
+        return
+
+    # No need to check for default profile, it will return 'default' by default
+    profile = get_session_profile_name()
+    click.echo(click.style("Using profile: " + profile, fg=CliColors.INFO.value))
+
+    update_eks_kubeconfig(region=region, profile=profile)
+    arn = get_aws_user_principal_arn()
+    access_entry_exists = False
+    # The user will need permission to list the access entries to check if they already have access to the cluster.
+    try:
+        access_entry_exists = is_existing_access_entry(arn)
+    except:
+        pass
+    if not access_entry_exists:
+        click.echo(click.style("Access entry does not exist or permission to check access entry is missing. Creating access entry...", fg=CliColors.INFO.value))
+        created_access_entry = create_user_access_entry(principal_arn=arn)
+        if created_access_entry:
+            click.echo(click.style("Successfully created the access entry.", fg=CliColors.SUCCESS.value))
+        else:
+            click.echo(click.style("Failed to create the access entry.", fg=CliColors.ERROR.value))
     click.echo("Successfully updated the kubeconfig file.")
 
 
@@ -632,7 +617,7 @@ def login():
     """
     click.echo("Opening the Tensorfuse dashboard in your default browser...")
     base_url = get_base_login_url()
-    click.launch(base_url + "/tensorfuse/login?tensorkube_login=True")
+    click.launch(base_url + "/tensorkube/login?tensorkube_login=True")
     run_server()
     track_event(Events.LOGGED_IN.value, {})
 
@@ -942,8 +927,8 @@ def deploy(name, gpus, gpu_type, cpu, memory, secret, max_scale, update, efs):
             f"Job with name {name} already exists. Please use a different name or use the --update flag to update the job.")
         return
 
-    depl_secrets, env_namespace, image_tag, cwd, sanitised_project_name = create_deployment_details(secret=secret,
-                                                                                                    env=env)
+    depl_secrets, env_namespace, image_tag = create_deployment_details(secret=secret, env=env)
+    cwd, sanitised_project_name = get_cwd_and_sanitised_project_name()
 
     if not cwd and not image_tag:
         return
@@ -967,6 +952,7 @@ def deploy(name, gpus, gpu_type, cpu, memory, secret, max_scale, update, efs):
     end_time = time.time() * 1000
     track_event(Events.JOB_DEPLOY_END.value,
                 {"start_time": start_time, "end_time": end_time, "duration": end_time - start_time})
+    click.echo("Now you can view your Jobs at: " + click.style(f"{get_base_frontend_url()}/jobs/", fg='cyan'))
 
 
 @job.command()
@@ -991,6 +977,7 @@ def queue(job_name: str, job_id: str, payload: str):
     """
     queue_job(job_name, job_id, payload)
     click.echo("Job queued successfully.")
+    click.echo("Now you can view the status of your Job queue at: " + click.style(f"{get_base_frontend_url()}/jobs/{job_name}", fg='cyan'))
 
 
 @job.command()
@@ -1037,6 +1024,102 @@ def logs(job_name):
     display_job_logs(job_prefix=job_name, namespace='keda', container_name="sqs-job-1")
 
 
+
+@job.group()
+def oneshot():
+    """IN ALPHA; DO NOT USE. Manage and deploy one-shot jobs on Tensorfuse.
+    """
+    pass
+
+
+@oneshot.command()
+@click.option('--config-file', required=False, type=click.Path(exists=True, dir_okay=False, readable=True),
+              help='Path to the config.yaml file.')
+def deploy(config_file):
+
+    try:
+        config = Config(config_file)
+    except Exception as e:
+        click.echo(f"Failed to read config.yaml file: {e}")
+        return
+
+    (config.set_if_not_exist('name', None)
+        .set_if_not_exist('gpus', DEFAULT_GPUS)
+        .set_if_not_exist('gpu_type', DEFAULT_GPU_TYPE)
+        .set_if_not_exist('cpu', DEFAULT_CPU)
+        .set_if_not_exist('memory', DEFAULT_MEMORY)
+        .set_if_not_exist('env', DEFAULT_ENV)
+        .set_if_not_exist('github_actions', DEFAULT_GITHUB_ACTIONS)
+        .set_if_not_exist('secret', [])
+        .set_if_not_exist('entrypoint', DEFAULT_ENTRYPOINT)
+        .set_if_not_exist('follow', DEFAULT_FOLLOW)
+        #All after this are not required for jobs
+        .set_if_not_exist('domain_name', DEFAULT_DOMAIN_NAME)
+        .set_if_not_exist('efs', False)
+        .set_if_not_exist('concurrency', None)
+        .set_if_not_exist('port', None)
+        .set_if_not_exist('min_scale', None)
+        .set_if_not_exist('max_scale', None))
+
+    # flags validation
+    if config.get('gpus') > 0:
+        if not config.get('gpu_type'):
+            click.echo(click.style("Error: GPU type is required when GPUs are specified.", fg=CliColors.ERROR.value))
+            return
+
+
+    if config.get('gpus') not in [0, 1, 4, 8]:
+        if config.get('github_actions'):
+            raise Exception("Error: Invalid number of GPUs. Only supported values are 0, 1, 4, and 8.")
+        click.echo('Error: Invalid number of GPUs. Only supported values are 0, 1, 4, and 8.')
+        return
+
+
+    click.echo(click.style("Preparing image details", fg=CliColors.INFO.value))
+    cwd, sanitised_project_name = get_cwd_and_sanitised_project_name()
+    depl_secrets, env_namespace, image_tag = create_deployment_details(
+        secret=config.get('secret'),
+        env=config.get('env'))
+    if not image_tag:
+        return
+
+    repo_url = get_or_create_ecr_repository(sanitised_project_name)
+    image_url = f"{repo_url}:{image_tag}"
+
+    convert_to_nydus_image = True if config.get('gpus') > 0 else False
+    click.echo(click.style("Starting the build process...", fg=CliColors.INFO.value))
+
+    click.echo("Running pre-flight checks...")
+    checks_successful = run_deployment_config_pre_flight_checks(config)
+    if not checks_successful:
+        click.echo("Deployment checks failed. Please check the logs for more details.")
+        return
+    click.echo("Pre-flight checks completed.")
+    click.echo("Pre-flight checks passed.")
+
+    pod_status = build_app(env=config.get('env'), image_tag=image_tag, sanitised_project_name=sanitised_project_name,
+                           upload_to_nfs=False, image_url=image_url, convert_to_nydus_image=convert_to_nydus_image,
+                           secrets=config.get('secret'))
+
+    if config.get('gpus') > 0:
+        image_url = get_nydus_image_url(image_url=image_url)
+
+    if pod_status == 'Succeeded' or pod_status == 'Completed':
+        click.echo("Build successful. Deploying the job...")
+        deploy_one_shot_job(name=config.get('name'), gpus=config.get('gpus'), gpu_type=config.get('gpu_type'),
+                            cpu=config.get('cpu'), memory=config.get('memory'), env=config.get('env'),
+                            entrypoint=config.get('entrypoint'), secrets=depl_secrets, image_url=image_url,
+                            sanitised_project_name=sanitised_project_name,follow=config.get('follow'))
+    else:
+        if config.get('github_actions'):
+            raise Exception("Failed to build the Docker image. Please check the logs for more details. Pod status: {}".format(
+                pod_status))
+        else:
+            click.echo("Failed to build the Docker image. Please check the logs for more details. Pod status: {}".format(
+                pod_status))
+
+
+
 @tensorkube.group()
 def domain():
     """Manage custom domain names and TLS for your Tensorkube cluster.
