@@ -464,16 +464,28 @@ def delete_generic_cfn_stack(stack_name: str):
     return response
 
 
-def update_generic_cloudformation_stack(stack_name: str, template_file_path: str, parameters: List[Dict[str, str]],
+def update_generic_cloudformation_stack(stack_name: str, template_url: str, parameters: List[Dict[str, str]],
                                         capabilities: List[str] = DEFAULT_CAPABILITIES):
     cloudformation_client = get_cloudformation_client()
-    file_name = resource_filename('tensorkube', template_file_path)
 
-    with open(file_name) as file:
-        template = file.read()
-
-    response = cloudformation_client.update_stack(StackName=stack_name, TemplateBody=template, Parameters=parameters,
+    response = cloudformation_client.update_stack(StackName=stack_name, TemplateURL=template_url, Parameters=parameters,
                                                   Capabilities=capabilities)
 
     stream_stack_events(stack_name)
     return response
+
+
+def get_stack_parameter_value(stack_name: str, parameter_key: str) -> Optional[str]:
+    cloudformation_client = get_cloudformation_client()
+
+    try:
+        response = cloudformation_client.describe_stacks(StackName=stack_name)
+        stack = response['Stacks'][0]
+        for param in stack.get('Parameters', []):
+            if param['ParameterKey'] == parameter_key:
+                return param['ParameterValue']
+        print(f"Parameter '{parameter_key}' not found in stack '{stack_name}'.")
+    except cloudformation_client.exceptions.ClientError as e:
+        print(f"Error retrieving stack: {e}")
+
+    return None
