@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 import time
 import uuid
 from typing import Optional, Dict, List
@@ -12,9 +13,9 @@ from tensorkube.helpers import  sanitise_name, \
     extract_command_from_dockerfile, extract_workdir_from_dockerfile
 
 from tensorkube.constants import DEFAULT_NAMESPACE, BUILD_TOOL, PodStatus, CliColors
-from tensorkube.services.aws_service import get_credentials, get_bucket_name, are_credentials_valid
+from tensorkube.services.aws_service import get_credentials, are_credentials_valid
 from tensorkube.services.environment_service import check_environment_exists
-from tensorkube.services.s3_service import  upload_files_in_parallel, empty_s3_folder
+from tensorkube.services.s3_service import  upload_files_in_parallel, empty_s3_folder, get_bucket_name
 
 from tensorkube.services.build import apply_k8s_buildkit_config
 
@@ -32,15 +33,26 @@ DEFAULT_MAX_SCALE = 3
 DEFAULT_GITHUB_ACTIONS = False
 DEFAULT_ENV = None
 DEFAULT_SECRET = None
+DEFAULT_DOMAIN_NAME = None
+DEFAULT_ENTRYPOINT = None
+DEFAULT_BUILD_CONTEXT = "."
+MAX_DEPLOYMENT_NAME_LENGTH=15
 
 
-def upload_build_context_to_s3(bucket_name, sanitised_project_name, cwd):
+def upload_build_context_to_s3(bucket_name, sanitised_project_name, work_dir):
     # TODO: figure out how to upload only the updated files to the s3 bucket
     click.echo("Deleting any outdated files in the S3 bucket...")
     empty_s3_folder(bucket_name=bucket_name, folder_name="build/" + sanitised_project_name + "/")
 
     click.echo("Uploading the current directory to the S3 bucket...")
-    upload_files_in_parallel(bucket_name=bucket_name, folder_path=cwd, s3_path="build/" + sanitised_project_name + "/")
+    upload_files_in_parallel(bucket_name=bucket_name, folder_path=work_dir, s3_path="build/" + sanitised_project_name + "/")
+
+
+def get_cwd_and_sanitised_project_name(build_context: str = "."):
+    working_directory = os.path.abspath(build_context)
+    non_sanitised_name = os.path.basename(working_directory)
+    sanitised_project_name = sanitise_name(non_sanitised_name)
+    return working_directory, sanitised_project_name
 
 
 def create_deployment_details(secret: list, env: str):
@@ -62,25 +74,26 @@ def create_deployment_details(secret: list, env: str):
                 return None, None, None, None, None
 
     image_tag = uuid.uuid4().hex
-    cwd = os.getcwd()
-    non_sanitised_name = os.path.basename(cwd)
-    sanitised_project_name = sanitise_name(non_sanitised_name)
 
-    return secrets, env_namespace, image_tag, cwd, sanitised_project_name
+    return secrets, env_namespace, image_tag
 
 
-def build_app(env, sanitised_project_name, image_tag, upload_to_nfs: bool = False, image_url: Optional[str] = None, convert_to_nydus_image: bool= False,
-              work_dir: str = os.getcwd(), secrets: List[str] = []):
-    is_dockerfile_present = False
-    for root, dirs, files in os.walk(work_dir):
-        for file in files:
-            local_file = os.path.join(root, file)
-            if local_file == work_dir + "/Dockerfile":
-                is_dockerfile_present = True
+def build_app(env, sanitised_project_name, image_tag, upload_to_nfs: bool = False,
+              image_url: Optional[str] = None, convert_to_nydus_image: bool= False, work_dir: str = os.getcwd(),
+              secrets: List[str] = [], dockerfile: str = "Dockerfile"):
+
+    dockerfile = os.path.abspath(dockerfile)
+    is_dockerfile_present = os.path.exists(dockerfile)
+    work_dir = os.path.abspath(work_dir)
 
     if not is_dockerfile_present:
         click.echo("No Dockerfile found in current directory.")
         return
+    try:
+        relative_dockerfile_path = Path(dockerfile).relative_to(Path(work_dir))
+    except ValueError:
+        click.echo("Dockerfile not inside the build context.")
+        return
 
     bucket_name = get_bucket_name(env_name=env)
 
@@ -101,10 +114,13 @@ def build_app(env, sanitised_project_name, image_tag, upload_to_nfs: bool = Fals
     else:
         click.echo("The AWS credentials have expired. Please update the credentials.")
         return
-    upload_build_context_to_s3(bucket_name=bucket_name, sanitised_project_name=sanitised_project_name, cwd=work_dir)
+    #TODO: update logic to upload specified build context to sanitised project name folder in s3 bucket
+    upload_build_context_to_s3(bucket_name=bucket_name, sanitised_project_name=sanitised_project_name, work_dir=work_dir)
     click.echo("Building the Docker image...")
     
-    apply_k8s_buildkit_config(sanitised_project_name=sanitised_project_name, image_tag=image_tag, env_name=env, image_url=image_url, upload_to_nfs=upload_to_nfs,convert_to_nydus_image=convert_to_nydus_image, secrets=secrets)
+    apply_k8s_buildkit_config(sanitised_project_name=sanitised_project_name, image_tag=image_tag, env_name=env,
+                              image_url=image_url, upload_to_nfs=upload_to_nfs, secrets=secrets,
+                              convert_to_nydus_image=convert_to_nydus_image, relative_dockerfile_path=str(relative_dockerfile_path))
     build_job_pod_name = get_pod_name_corresponing_to_job(job_name=build_job_name, namespace=env_namespace)
     if build_job_pod_name is None:
         click.echo("Build Pod not found")
@@ -133,7 +149,7 @@ def build_app(env, sanitised_project_name, image_tag, upload_to_nfs: bool = Fals
     return pod_status
 
 def deploy_knative_service(env: str, gpus: int, gpu_type: str, cpu: float, memory: float, min_scale: int, max_scale: int, concurrency: int,
-                           pod_status: str, cwd: str, sanitised_project_name: str, image_url: str, secrets: list, port: int, domain: Optional[str],
+                           pod_status: str, dockerfile: str, sanitised_project_name: str, image_url: str, secrets: list, port: int, domain: Optional[str],
                            enable_efs: bool = False, github_actions: bool = DEFAULT_GITHUB_ACTIONS, readiness: Optional[Dict] = None,
                            startup_probe: Optional[Dict] = None, liveness_probe: Optional[Dict] = None, volumes: Optional[List[Dict]] = None):
     env_namespace = DEFAULT_NAMESPACE if not env else env
@@ -141,7 +157,7 @@ def deploy_knative_service(env: str, gpus: int, gpu_type: str, cpu: float, memor
     if pod_status == 'Succeeded' or pod_status == 'Completed':
         click.echo("Successfully built and pushed the Docker image.")
         yaml_file_path = resource_filename('tensorkube', 'configurations/build_configs/knative_base_config.yaml')
-        dockerfile_path = cwd + "/Dockerfile"
+        dockerfile_path = dockerfile
         workdir = extract_workdir_from_dockerfile(dockerfile_path)
         command = extract_command_from_dockerfile(dockerfile_path)
         service_name = f"{sanitised_project_name}-gpus-{gpus}-{str(gpu_type).lower()}"
