@@ -1,6 +1,5 @@
-import boto3
-from tensorkube.constants import REGION, get_cluster_name
-
+from tensorkube.constants import get_cluster_name
+from tensorkube.services.aws_service import get_dynamodb_resource
 
 def get_dynamodb_table_name():
     return f"{get_cluster_name()}-job-status"
@@ -12,8 +11,8 @@ def get_user_dynamodb_access_policy_name(user: str):
     return f"{get_cluster_name()}-{user}-dynamodb-access-policy"
 
 
-def get_all_job_statuses(region: str = REGION, limit: int = 3):
-    dynamodb = boto3.resource('dynamodb', region_name=region)
+def get_all_job_statuses(limit: int = 3):
+    dynamodb = get_dynamodb_resource()
     table_name = get_dynamodb_table_name()
     table = dynamodb.Table(table_name)
 
@@ -62,7 +61,7 @@ def get_all_job_statuses(region: str = REGION, limit: int = 3):
 
 
 def get_job_statuses(job_name: str):
-    dynamodb = boto3.resource('dynamodb', region_name=REGION)
+    dynamodb = get_dynamodb_resource()
     table_name = get_dynamodb_table_name()
     table = dynamodb.Table(table_name)
 
