@@ -1,7 +1,6 @@
 import subprocess
 import time
-from typing import Optional
-
+from typing import Optional, List
 import boto3
 import click
 from botocore.exceptions import ClientError
@@ -9,8 +8,8 @@ from kubernetes import config, client
 from kubernetes.client import ApiException
 
 from tensorkube.configurations.configuration_urls import KNATIVE_CRD_URL, KNATIVE_CORE_URL
-from tensorkube.constants import REGION, get_cluster_name
-from tensorkube.services.aws_service import get_eks_client, get_karpenter_version, get_karpenter_namespace
+from tensorkube.constants import get_cluster_name
+from tensorkube.services.aws_service import get_eks_client, get_karpenter_version, get_karpenter_namespace, get_eks_client, get_ec2_client, get_session_region, get_session_profile_name
 from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name
 
 
@@ -41,14 +40,14 @@ def describe_cluster(cluster_name):
 
 
 def get_eks_cluster_vpc_config(cluster_name):
-    eks_client = boto3.client('eks')
+    eks_client = get_eks_client()
     response = eks_client.describe_cluster(name=cluster_name)
     vpc_config = response['cluster']['resourcesVpcConfig']
     return vpc_config
 
 
 def get_vpc_cidr(vpc_id):
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
     response = ec2_client.describe_vpcs(VpcIds=[vpc_id])
     cidr_range = response['Vpcs'][0]['CidrBlock']
     print(f"VPC CIDR Range: {cidr_range}")
@@ -56,7 +55,7 @@ def get_vpc_cidr(vpc_id):
 
 
 def get_security_group_id_by_name(group_name):
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
     response = ec2_client.describe_security_groups(Filters=[{'Name': 'group-name', 'Values': [group_name]}])
     security_groups = response.get('SecurityGroups', [])
     if not security_groups:
@@ -66,13 +65,6 @@ def get_security_group_id_by_name(group_name):
 
 
 def install_karpenter():
-    # Logout from helm registry
-    logout_command = ["helm", "registry", "logout", "public.ecr.aws"]
-    try:
-        subprocess.run(logout_command, check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-    except Exception as e:
-        pass
-
     # Install/upgrade karpenter
     install_command = ["helm", "upgrade", "--install", "karpenter", "oci://public.ecr.aws/karpenter/karpenter",
                        "--version", get_karpenter_version(), "--namespace", get_karpenter_namespace(),
@@ -81,13 +73,26 @@ def install_karpenter():
                        "controller.resources.requests.cpu=1", "--set", "controller.resources.requests.memory=1Gi",
                        "--set", "controller.resources.limits.cpu=1", "--set", "controller.resources.limits.memory=1Gi",
                        "--wait"]
+
+    install_karpenter_with_command(install_command)
+
+
+def install_karpenter_with_command(install_command: List[str]):
+    # Logout from helm registry
+    logout_command = ["helm", "registry", "logout", "public.ecr.aws"]
+    try:
+        subprocess.run(logout_command, check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+    except Exception as e:
+        pass
+
     try:
         subprocess.run(install_command, check=True)
     except Exception as e:
         print(f"Error while installing karpenter: {e}")
         # now try running by logging into ecr
-        # aws ecr get-login-password --region your-region | helm registry login --username AWS --password-stdin public.ecr.aws
-        login_command = ["aws", "ecr-public", "get-login-password", "--region", REGION, "|", "helm", "registry", "login",
+        # TODO: check if the login command is correct. Giving error rn. maybe it is never run
+        region = get_session_region()
+        login_command = ["aws", "ecr-public", "get-login-password", "--region", region, "|", "helm", "registry", "login",
                          "--username", "AWS", "--password-stdin", "public.ecr.aws"]
         try:
             subprocess.run(login_command, check=True)
@@ -137,8 +142,17 @@ def delete_keda_from_cluster():
     subprocess.run(command, check=True)
 
 
-def update_eks_kubeconfig(region: str = REGION):
-    command = ["aws", "eks", "update-kubeconfig", "--name", get_cluster_name(), "--region", region]
+def update_eks_kubeconfig(region: Optional[str] = None, profile: Optional[str] = None):
+    if not region:
+        region = get_session_region()
+    if not profile:
+        profile = get_session_profile_name()
+    
+    # for IAM users, we don't need to pass the profile
+    if profile == "default":
+        command = ["aws", "eks", "update-kubeconfig", "--name", get_cluster_name(), "--region", region]
+    else:
+        command = ["aws", "eks", "update-kubeconfig", "--name", get_cluster_name(), "--region", region, "--profile", profile]
     subprocess.run(command, check=True)
 
 
@@ -210,13 +224,13 @@ def delete_knative_core():
 
 
 def get_cluster_oidc_issuer_url(cluster_name):
-    client = boto3.client('eks')
+    client = get_eks_client()
     response = client.describe_cluster(name=cluster_name)
     return response['cluster']['identity']['oidc']['issuer']
 
 
-def create_eks_addon(cluster_name, addon_name, account_no, mountpoint_driver_role_name, region=REGION):
-    client = boto3.client('eks', region_name=region)
+def create_eks_addon(cluster_name, addon_name, account_no, mountpoint_driver_role_name):
+    client = get_eks_client()
     try:
         # Check if the addon already exists
         client.describe_addon(clusterName=cluster_name, addonName=addon_name)
@@ -233,8 +247,8 @@ def create_eks_addon(cluster_name, addon_name, account_no, mountpoint_driver_rol
             raise e
 
 
-def delete_eks_addon(cluster_name: str, addon_name:str, region:str=REGION):
-    client = boto3.client('eks', region_name=region)
+def delete_eks_addon(cluster_name: str, addon_name:str):
+    client = get_eks_client()
     try:
         # Attempt to delete the addon
         client.delete_addon(clusterName=cluster_name, addonName=addon_name)
@@ -265,7 +279,7 @@ def delete_eks_addon(cluster_name: str, addon_name:str, region:str=REGION):
 
 def get_nodegroup_status(cluster_name, nodegroup_name):
     # Create an EKS client
-    eks_client = boto3.client('eks')
+    eks_client = get_eks_client()
 
     # Describe the nodegroup
     response = eks_client.describe_nodegroup(clusterName=cluster_name, nodegroupName=nodegroup_name)
@@ -275,9 +289,9 @@ def get_nodegroup_status(cluster_name, nodegroup_name):
 
     return status
 
-
+# TODO: send region for IAM users
 def is_existing_access_entry(principal_arn: str):
-    eks_client = boto3.client('eks')
+    eks_client = get_eks_client()
     cluster_name = get_cluster_name()
     response = eks_client.list_access_entries(clusterName=cluster_name)
     for entry in response.get('accessEntries', []):
@@ -287,7 +301,7 @@ def is_existing_access_entry(principal_arn: str):
 
 
 def give_eks_cluster_access(principal_arn: str):
-    eks_client = boto3.client('eks')
+    eks_client = get_eks_client()
     cluster_name = get_cluster_name()
     policy_arn = 'arn:aws:eks::aws:cluster-access-policy/AmazonEKSClusterAdminPolicy'
 
