@@ -11,7 +11,7 @@ from pkg_resources import resource_filename
 
 from tensorkube.constants import CliColors, LOCKED_EKSCTL_VERSION
 from tensorkube.constants import get_cluster_name
-from tensorkube.services.aws_service import get_aws_account_id, get_karpenter_namespace
+from tensorkube.services.aws_service import get_aws_account_id, get_karpenter_namespace, get_session_region
 from tensorkube.services.error import CLIVersionError
 
 
@@ -19,7 +19,8 @@ from tensorkube.services.error import CLIVersionError
 def create_base_tensorkube_cluster_eksctl(cluster_name, vpc_public_subnets: List[str] = [], vpc_private_subnets: List[str]=[]):
     yaml_file_path = resource_filename('tensorkube', 'configurations/base_cluster.yaml')
     # variables
-    variables = {"CLUSTER_NAME": cluster_name, "AWS_DEFAULT_REGION": "us-east-1", "K8S_VERSION": "1.29",
+    region = get_session_region()
+    variables = {"CLUSTER_NAME": cluster_name, "AWS_DEFAULT_REGION": region, "K8S_VERSION": "1.29",
                  "AWS_ACCOUNT_ID": get_aws_account_id(), "KARPENTER_NAMESPACE": get_karpenter_namespace(),
                  "AWS_PARTITION": "aws", }
 
