@@ -1,16 +1,16 @@
 import json
 from typing import Optional
-
-import boto3
+import time
 import click
 import yaml
 import subprocess
 from kubernetes import config, client, utils
 from pkg_resources import resource_filename
+from botocore.exceptions import ClientError
 
-from tensorkube.constants import NAMESPACE, REGION, get_efs_service_account_name, get_efs_role_name, get_cluster_name, \
+from tensorkube.services.aws_service import get_aws_account_id, get_iam_client, get_eks_client, get_efs_client, get_ec2_client
+from tensorkube.constants import NAMESPACE, get_efs_service_account_name, get_efs_role_name, get_cluster_name, \
     DEFAULT_NAMESPACE, get_efs_security_group_name, CliColors
-from tensorkube.services.aws_service import get_aws_account_id
 from tensorkube.services.cloudformation_service import create_cloudformation_stack, stream_stack_events, \
     get_stack_status_from_stack_name, CfnStackStatus, deploy_generic_cloudformation_stack, get_cfn_stack_export_values, \
     delete_generic_cfn_stack
@@ -54,7 +54,6 @@ def get_efs_vol_pvc_name(volume_name: str, namespace: str = DEFAULT_NAMESPACE):
 def create_efs_driver_role(account_no: str, role_name: str, oidc_issuer_url: str, namespace: str,
                            service_account_name: str):
     oidc_issuer = oidc_issuer_url[8:]
-    region = oidc_issuer.split('.')[2]
     trust_policy_file_path = resource_filename('tensorkube',
                                                'configurations/aws_configs/aws_efs_csi_driver_trust_policy.json')
     with open(trust_policy_file_path, 'r') as f:
@@ -64,7 +63,7 @@ def create_efs_driver_role(account_no: str, role_name: str, oidc_issuer_url: str
     trust_policy['Statement'][0]['Condition']['StringEquals'] = {
         "{}:sub".format(oidc_issuer): "system:serviceaccount:{}:{}".format(namespace, service_account_name),
         "{}:aud".format(oidc_issuer): "sts.amazonaws.com"}
-    iam_client = boto3.client('iam', region_name=region)
+    iam_client = get_iam_client()
     try:
         # Check if the IAM role already exists
         iam_client.get_role(RoleName=role_name)
@@ -81,11 +80,10 @@ def create_efs_driver_role(account_no: str, role_name: str, oidc_issuer_url: str
 
 
 def create_efs_role_with_policy(cluster_name, account_no, role_name,
-                                service_account_name=get_efs_service_account_name(), namespace=NAMESPACE,
-                                region=REGION):
+                                service_account_name=get_efs_service_account_name(), namespace=NAMESPACE):
     oidc_issuer_url = get_cluster_oidc_issuer_url(cluster_name)
     create_efs_driver_role(account_no, role_name, oidc_issuer_url, namespace, service_account_name)
-    iam_client = boto3.client('iam', region_name=region)
+    iam_client = get_iam_client()
     response = iam_client.attach_role_policy(PolicyArn='arn:aws:iam::aws:policy/service-role/AmazonEFSCSIDriverPolicy',
                                              RoleName=role_name, )
     return response
@@ -93,7 +91,7 @@ def create_efs_role_with_policy(cluster_name, account_no, role_name,
 
 def create_efs_addon():
     # Execute the shell commands
-    eks_client = boto3.client('eks', region_name=REGION)
+    eks_client = get_eks_client()
     addon_name = 'aws-efs-csi-driver'
     cluster_name = get_cluster_name()
     service_account_role_arn = f'arn:aws:iam::{get_aws_account_id()}:role/{get_efs_role_name()}'
@@ -114,7 +112,7 @@ def create_efs_addon():
 
 
 def create_efs_filesystem(name):
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
 
     try:
         # Describe file systems
@@ -147,7 +145,7 @@ def create_efs_filesystem(name):
 
 
 def get_efs_filesystem_by_name(name: str):
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
 
     # Get all file systems
     response = efs_client.describe_file_systems()
@@ -166,7 +164,7 @@ def get_efs_filesystem_by_name(name: str):
 
 
 def wait_for_efs_filesystem(filesystem_id):
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
     while True:
         response = efs_client.describe_file_systems(FileSystemId=filesystem_id)
         lifecycle_state = response['FileSystems'][0]['LifeCycleState']
@@ -178,7 +176,7 @@ def wait_for_efs_filesystem(filesystem_id):
 
 
 def create_security_group(vpc_id, env: Optional[str] = None):
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
     group_name = get_efs_security_group_name(env=env)
     # Check if the security group already exists
     try:
@@ -202,7 +200,7 @@ def create_security_group(vpc_id, env: Optional[str] = None):
 
 
 def authorize_security_group_ingress(security_group_id, cidr_range):
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
 
     # Describe existing security group rules
     response = ec2_client.describe_security_groups(GroupIds=[security_group_id])
@@ -230,19 +228,19 @@ def authorize_security_group_ingress(security_group_id, cidr_range):
 
 
 def get_az_from_subnet(subnet_id):
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
     response = ec2_client.describe_subnets(SubnetIds=[subnet_id])
     return response['Subnets'][0]['AvailabilityZone']
 
 
 def is_public_subnet(subnet_id, region='us-east-1'):
-    ec2 = boto3.client('ec2', region_name=region)
+    ec2_client = get_ec2_client()
 
     # Get subnet details
-    subnet = ec2.describe_subnets(SubnetIds=[subnet_id])['Subnets'][0]
+    subnet = ec2_client.describe_subnets(SubnetIds=[subnet_id])['Subnets'][0]
 
     # Get the route table associated with the subnet
-    route_table_associations = ec2.describe_route_tables(
+    route_table_associations = ec2_client.describe_route_tables(
         Filters=[{'Name': 'association.subnet-id', 'Values': [subnet_id]}]
     )['RouteTables']
 
@@ -265,7 +263,7 @@ def is_public_subnet(subnet_id, region='us-east-1'):
 
 
 def create_efs_mount_targets(filesystem_id, subnets, security_group_id):
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
 
     # Get existing mount targets for the file system
     existing_mount_targets = efs_client.describe_mount_targets(FileSystemId=filesystem_id)['MountTargets']
@@ -393,14 +391,16 @@ def is_existing_efs_storage_class(context_name: Optional[str] = None):
 
 
 def create_efs_volume_k8s_resources(volume_name: str, efs_id: str, env: Optional[str] = None) -> bool:
-    chart_path = resource_filename("tensorkube", 'configurations/helm-charts/volumes/efs-volume')
     namespace = env if env else DEFAULT_NAMESPACE
     #TODO: use appropriate cluster context
 
+    efs_volume_chart_version = "0.1.0"
     try:
         subprocess.run(
-            ["helm", "upgrade", "--install", f"efs-volume-{volume_name}-{namespace}", chart_path, "--create-namespace",
-             "--namespace", namespace, "--set", f"volumeName={volume_name}", "--set", f"namespace={namespace}",
+            ["helm", "upgrade", "--install", f"efs-volume-{volume_name}-{namespace}",
+            "oci://public.ecr.aws/q0m5o9l2/tensorfuse/helm-charts/volumes/efs-volume", "--version",
+             efs_volume_chart_version, "--create-namespace", "--namespace", namespace,
+             "--set", f"volumeName={volume_name}", "--set", f"namespace={namespace}",
              "--set", f"fileSystemId={efs_id}"], check=True,
         )
         return True
@@ -542,7 +542,7 @@ def apply_efs_pvc(env: Optional[str] = None, context_name: Optional[str] = None)
 
 
 def delete_efs_filesystem(name: str):
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
     filesystem = get_efs_filesystem_by_name(name)
     if filesystem:
         filesystem_id = filesystem['FileSystemId']
@@ -568,13 +568,8 @@ def delete_efs_filesystem(name: str):
     else:
         print(f"EFS File System with name {name} not found")
 
-
-import time
-from botocore.exceptions import ClientError
-
-
 def delete_efs_addon():
-    eks_client = boto3.client('eks', region_name=REGION)
+    eks_client = get_efs_client()
     addon_name = 'aws-efs-csi-driver'
     cluster_name = get_cluster_name()
     try:
@@ -610,7 +605,7 @@ def delete_security_group(security_group_name: str):
     security_group_id = get_security_group_id_by_name(security_group_name)
     if not security_group_id:
         return
-    ec2_client = boto3.client('ec2')
+    ec2_client = get_ec2_client()
     ec2_client.delete_security_group(GroupId=security_group_id)
     print(f"Security Group {security_group_id} deleted")
 
@@ -676,7 +671,7 @@ def delete_efs_directory_for_deployment(sanitised_project_name: str, env: Option
 
 
 def list_efs_volumes():
-    efs_client = boto3.client('efs')
+    efs_client = get_efs_client()
     response = efs_client.describe_file_systems()
     file_systems = response['FileSystems']
     efs_volume_list = []
