@@ -6,13 +6,13 @@ from botocore.exceptions import ClientError
 from pkg_resources import resource_filename
 from typing import Dict
 
-from tensorkube.constants import REGION, get_cluster_name, CliColors
-from tensorkube.services.aws_service import get_aws_account_id
+from tensorkube.constants import get_cluster_name, CliColors
+from tensorkube.services.aws_service import get_aws_account_id, get_iam_client, get_sts_client, get_session_region
 
 
-def create_iam_policy(policy_name: str, policy_document: Dict, region: str = REGION):
-    iam = boto3.client('iam', region_name=region)
-    sts = boto3.client('sts')
+def create_iam_policy(policy_name: str, policy_document: Dict):
+    iam = get_iam_client()
+    sts = get_sts_client()
     try:
         # Check if the IAM policy already exists
         account_id = sts.get_caller_identity()['Account']
@@ -31,26 +31,28 @@ def create_iam_policy(policy_name: str, policy_document: Dict, region: str = REG
             raise e
 
 
-def create_mountpoint_iam_policy(policy_name, bucket_name, region=REGION):
+def create_mountpoint_iam_policy(policy_name, bucket_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/mountpoint_policy.json')
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     for statement in policy['Statement']:
         statement['Resource'] = [r.replace('USER_BUCKET', bucket_name) for r in statement['Resource']]
 
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
 
-def create_sqs_access_policy(policy_name, region=REGION):
+def create_sqs_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/sqs_access_policy.json')
+    region = get_session_region()
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     for statement in policy['Statement']:
         statement['Resource'] = f"arn:aws:sqs:{region}:{get_aws_account_id()}:{get_cluster_name()}-*"
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
-def create_dynamo_access_policy(policy_name, region=REGION):
+def create_dynamo_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/dynamo_access_policy.json')
+    region = get_session_region()
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     for statement in policy['Statement']:
@@ -59,14 +61,13 @@ def create_dynamo_access_policy(policy_name, region=REGION):
         resource = resource.replace('ACCOUNT_NO', get_aws_account_id())
         resource = resource.replace('TABLE_NAME', f"{get_cluster_name()}-*")
         statement['Resource'] = resource
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
 
 
 def create_iam_role_with_service_account_cluster_access(account_no: str, oidc_issuer_url: str, role_name: str,
-                                                        service_account_name: str, namespace: str, region: str=REGION):
+                                                        service_account_name: str, namespace: str):
     oidc_issuer = oidc_issuer_url[8:]
-    region = oidc_issuer.split('.')[2]
     trust_policy_file_path = resource_filename('tensorkube',
                                                'configurations/aws_configs/iam_role_cluster_access_trust_policy.json')
     with open(trust_policy_file_path, 'r') as f:
@@ -77,7 +78,7 @@ def create_iam_role_with_service_account_cluster_access(account_no: str, oidc_is
         "{}:sub".format(oidc_issuer): "system:serviceaccount:{}:{}".format(namespace, service_account_name),
         "{}:aud".format(oidc_issuer): "sts.amazonaws.com"}
 
-    iam = boto3.client('iam', region_name=region)
+    iam = get_iam_client()
 
     try:
         # Check if the IAM role already exists
@@ -97,9 +98,8 @@ def create_iam_role_with_service_account_cluster_access(account_no: str, oidc_is
 
 
 def create_or_update_iam_role_with_service_account_cluster_access(account_no: str, oidc_issuer_url: str, role_name: str,
-                                                        service_account_name: str, namespace: str, region: str=REGION):
+                                                        service_account_name: str, namespace: str):
     oidc_issuer = oidc_issuer_url[8:]
-    region = oidc_issuer.split('.')[2]
     trust_policy_file_path = resource_filename('tensorkube',
                                                'configurations/aws_configs/iam_role_cluster_access_trust_policy.json')
     with open(trust_policy_file_path, 'r') as f:
@@ -111,7 +111,7 @@ def create_or_update_iam_role_with_service_account_cluster_access(account_no: st
         "{}:aud".format(oidc_issuer): "sts.amazonaws.com"
     }
 
-    iam = boto3.client('iam', region_name=region)
+    iam = get_iam_client()
 
     try:
         # Check if the IAM role already exists
@@ -162,28 +162,28 @@ def create_sqs_access_role(account_no: str, oidc_issuer_url: str, role_name: str
                                                         namespace)
 
 
-def attach_role_policy(account_no, policy_name, role_name, region=REGION):
-    client = boto3.client('iam', region_name=region)
+def attach_role_policy(account_no, policy_name, role_name):
+    client = get_iam_client()
     response = client.attach_role_policy(PolicyArn='arn:aws:iam::{}:policy/{}'.format(account_no, policy_name),
                                          RoleName=role_name, )
     return response
 
 
-def detach_role_policy(account_no, role_name, policy_name, region=REGION):
-    client = boto3.client('iam', region_name=region)
+def detach_role_policy(account_no, role_name, policy_name):
+    client = get_iam_client()
     response = client.detach_role_policy(PolicyArn='arn:aws:iam::{}:policy/{}'.format(account_no, policy_name),
                                          RoleName=role_name, )
     return response
 
 
-def delete_role(role_name, region=REGION):
-    client = boto3.client('iam', region_name=region)
+def delete_role(role_name):
+    client = get_iam_client()
     response = client.delete_role(RoleName=role_name)
     return response
 
 
-def delete_policy(account_no, policy_name, region=REGION):
-    client = boto3.client('iam', region_name=region)
+def delete_policy(account_no, policy_name):
+    client = get_iam_client()
     policy_arn = f'arn:aws:iam::{account_no}:policy/{policy_name}'
     #delete all policy versions
     policy = client.get_policy(PolicyArn=policy_arn)
@@ -197,15 +197,15 @@ def delete_policy(account_no, policy_name, region=REGION):
     return response
 
 
-def update_iam_policy(account_no, policy_name, policy_document, region=REGION):
-    client = boto3.client('iam', region_name=region)
+def update_iam_policy(account_no, policy_name, policy_document):
+    client = get_iam_client()
     response = client.create_policy_version(PolicyArn='arn:aws:iam::{}:policy/{}'.format(account_no, policy_name),
                                            PolicyDocument=json.dumps(policy_document), SetAsDefault=True)
     return response
 
 
 def delete_iam_role(role_name):
-    iam_client = boto3.client('iam')
+    iam_client = get_iam_client()
     attached_policies = iam_client.list_attached_role_policies(RoleName=role_name)['AttachedPolicies']
 
     # Detach policies
@@ -219,7 +219,7 @@ def delete_iam_role(role_name):
 
 
 def get_role_name_for_prefix(prefix: str):
-    iam = boto3.client('iam')
+    iam = get_iam_client()
     roles = []
     response = iam.list_roles()
     
@@ -236,8 +236,8 @@ def get_role_name_for_prefix(prefix: str):
             return role['RoleName']
     return None
 
-def create_iam_user(user_name, region=REGION):
-    iam = boto3.client('iam', region_name=region)
+def create_iam_user(user_name):
+    iam = get_iam_client()
     try:
         response = iam.create_user(UserName=user_name)
         print(f"IAM User '{user_name}' created successfully.")
@@ -246,8 +246,9 @@ def create_iam_user(user_name, region=REGION):
         print(f"IAM User '{user_name}' already exists.")
         return iam.get_user(UserName=user_name)['User']
 
-def create_eks_access_policy(policy_name, region=REGION):
+def create_eks_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/eks_access_policy.json')
+    region = get_session_region()
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     statements= []
@@ -259,41 +260,43 @@ def create_eks_access_policy(policy_name, region=REGION):
         statement['Resource'] = resource
         statements.append(statement)
     policy['Statement'] = statements
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
 
-def create_user_sqs_access_policy(policy_name, region=REGION):
+def create_user_sqs_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/user_sqs_access_policy.json')
+    region = get_session_region()
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     for statement in policy['Statement']:
         statement['Resource'] = f"arn:aws:sqs:{region}:{get_aws_account_id()}:{get_cluster_name()}-*"
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
-def create_user_s3_access_policy(policy_name, region=REGION):
+def create_user_s3_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/user_s3_access_policy.json')
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
-def create_user_dynamo_access_policy(policy_name, region=REGION):
+def create_user_dynamo_access_policy(policy_name):
     policy_file_path = resource_filename('tensorkube', 'configurations/aws_configs/user_dynamo_access_policy.json')
+    region = get_session_region()
     with open(policy_file_path, 'r') as f:
         policy = json.load(f)
     for statement in policy['Statement']:
         statement['Resource'] = f"arn:aws:dynamodb:{region}:{get_aws_account_id()}:table/{get_cluster_name()}-*"
-    return create_iam_policy(policy_name, policy, region)
+    return create_iam_policy(policy_name, policy)
 
 
 
-def attach_policy_to_user(policy_arn, user_name, region=REGION):
-    iam = boto3.client('iam', region_name=region)
+def attach_policy_to_user(policy_arn, user_name):
+    iam = get_iam_client()
     iam.attach_user_policy(UserName=user_name, PolicyArn=policy_arn)
     print(f"Policy '{policy_arn}' attached to user '{user_name}'.")
 
 
-def create_access_key(user_name, region=REGION):
-    iam = boto3.client('iam', region_name=region)
+def create_access_key(user_name):
+    iam = get_iam_client()
     response = iam.create_access_key(UserName=user_name)
     access_key = response['AccessKey']
     return access_key['AccessKeyId'], access_key['SecretAccessKey']
