@@ -9,6 +9,8 @@ import yaml
 from kubernetes import config, client
 from pkg_resources import resource_filename
 
+from tensorkube.configurations.cloudformation.configure.cluster_access_lambda_files.lambda_code import \
+    get_managed_node_group_name
 from tensorkube.configurations.configuration_urls import DOMAIN_SERVER_URL, KNATIVE_ISTIO_CONTROLLER_URL
 from tensorkube.constants import CliColors, LOCKED_ISTIO_VERSION, get_cluster_name
 from tensorkube.services.eks_service import get_pods_using_namespace, apply_yaml_from_url, delete_resources_from_url
@@ -65,7 +67,7 @@ def install_istio_on_cluster():
         values_file = resource_filename('tensorkube','configurations/istio/istio.yaml')
         with open(values_file, 'r') as f:
             values = yaml.safe_load(f)
-            nodegroup_name = f"{get_cluster_name()}-ng-bottlerocket"
+            nodegroup_name = get_managed_node_group_name(get_cluster_name())
             values['spec']['components']['ingressGateways'][0]['k8s']['affinity'][
                 'nodeAffinity']['requiredDuringSchedulingIgnoredDuringExecution'][
                 'nodeSelectorTerms'][0]['matchExpressions'][0]['values'][0] = nodegroup_name
