@@ -1,6 +1,5 @@
 import json
 import os
-
 import boto3
 import click
 import yaml
@@ -9,11 +8,12 @@ from kubernetes.client import ApiException
 from pkg_resources import resource_filename
 from typing import Optional, List
 
-from tensorkube.constants import REGION, get_cluster_name, CliColors, get_job_sidecar_iam_role_name, \
+from tensorkube.constants import get_cluster_name, CliColors,  get_job_sidecar_iam_role_name, \
     GPU_DEPLOYMENT_MIN_MEMORY, GPU_DEPLOYMENT_MIN_CPU
 from tensorkube.helpers import sanitise_name, extract_workdir_from_dockerfile, extract_command_from_dockerfile
-from tensorkube.services.aws_service import get_aws_account_id, get_bucket_name, get_credentials
+from tensorkube.services.aws_service import get_aws_account_id, get_credentials, get_dynamodb_resource, get_sqs_client, get_session_region
 from tensorkube.services.dynamodb_service import get_dynamodb_table_name, get_dynamodb_access_policy_name
+
 from tensorkube.services.eks_service import get_cluster_oidc_issuer_url, install_keda, delete_keda_from_cluster
 from tensorkube.services.environment_service import delete_environment, create_new_environment
 from tensorkube.services.filesystem_service import delete_efs_directory_for_deployment
@@ -25,13 +25,15 @@ from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name,
     create_k8s_role, create_role_binding, create_aws_secret, is_existing_scaled_job, generate_kubeconfig, \
     patch_service_account
 from tensorkube.services.knative_service import get_instance_family_from_gpu_type, get_supported_gpu_families
-from tensorkube.services.s3_access_service import get_s3_access_policy_name
 from tensorkube.services.s3_service import create_s3_bucket
+
+from tensorkube.services.s3_access_service import get_s3_access_policy_name
+
 from tensorkube.services.sqs_service import create_sqs_queue, queue_message, delete_sqs_queue, \
     get_sqs_access_policy_name
 from tensorkube.services.nydus import get_nydus_runtime_class_name
 from tensorkube.services.nodepool import get_gpu_nodepool
-
+from tensorkube.services.s3_service import get_bucket_name
 
 
 def create_cloud_resources_for_queued_job_support():
@@ -79,7 +81,7 @@ def create_cloud_resources_for_queued_job_support():
     create_aws_secret(get_credentials(),"keda")
     click.echo("S3 train bucket created for keda env")
 
-    create_table_for_job_status(region=REGION)
+    create_table_for_job_status()
 
 
 def create_trigger_authentication_for_aws_sqs(sqs_access_iam_role_arn: str, context_name: Optional[str] = None):
@@ -115,7 +117,7 @@ def get_queue_name_for_job(job_name: str):
 
 def get_job_queue_url_for_job(job_name: str):
     queue_name = get_queue_name_for_job(job_name)
-    sqs = boto3.client('sqs', region_name=REGION)
+    sqs = get_sqs_client()
     response = sqs.get_queue_url(QueueName=queue_name)
     return response['QueueUrl']
 
@@ -128,7 +130,7 @@ def is_existing_queued_job(job_name: str):
 
 
 def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memory: int, max_scale: int,
-               env: str , image_tag:str, update: bool = False, region: str = REGION, cwd: Optional[str] =None,
+               env: str , image_tag:str, update: bool = False, cwd: Optional[str] =None,
                sanitised_project_name: Optional[str] = None, secrets: List[str] = [],
                context_name: Optional[str] = None, job_type: Optional[str] = None, enable_efs: bool = False):
     click.echo("Deploying job...")
@@ -137,6 +139,7 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
         context_name = get_tensorkube_cluster_context_name()
         if not context_name:
             return None
+    region = get_session_region()
     k8s_api_client = config.new_client_from_config(context=context_name)
     k8s_client = client.CustomObjectsApi(k8s_api_client)
     if job_type == 'axolotl':
@@ -148,6 +151,7 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
         scaled_job_yaml = scaled_job_yaml.replace('${IMAGE_TAG}', image_tag)
         scaled_job_yaml = scaled_job_yaml.replace('${GPUS}', str(gpus))
         scaled_job_yaml = scaled_job_yaml.replace('${GPU_TYPE}', gpu_type)
+        scaled_job_yaml = scaled_job_yaml.replace('<REGION>', region)
         scaled_job_json = yaml.safe_load(scaled_job_yaml)
         job_queue_url = create_sqs_queue(get_queue_name_for_job(job_name))
 
@@ -156,7 +160,8 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
         scaled_job_json['spec']['triggers'][0]['metadata']['queueURL'] = job_queue_url
         scaled_job_json['spec']['jobTargetRef']['template']['spec']['containers'][0]['env'] = [
             {'name': 'AWS_REGION', 'value': region}, {'name': 'QUEUE_URL', 'value': job_queue_url},
-            {'name': 'JOB_NAME', 'value': job_name}, {'name': 'LORA_ADAPTER_BUCKET', 'value': bucket_name}]
+            {'name': 'JOB_NAME', 'value': job_name}, {'name': 'LORA_ADAPTER_BUCKET', 'value': bucket_name},
+            {'name': 'AWS_DEFAULT_REGION', 'value': region}]
         scaled_job_json['spec']['triggers'][0]['metadata']['region'] = region
         scaled_job_json['spec']['maxReplicaCount'] = max_scale
 
@@ -173,8 +178,9 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
     else:
         scaled_job_file_path = resource_filename('tensorkube', 'configurations/build_configs/scaled_job.yaml')
         with open(scaled_job_file_path, 'r') as f:
-            scaled_job_json = yaml.safe_load(f)
-
+            scaled_job_yaml = f.read()
+        scaled_job_yaml = scaled_job_yaml.replace('<REGION>', region)
+        scaled_job_json = yaml.safe_load(scaled_job_yaml)
         job_queue_url = create_sqs_queue(get_queue_name_for_job(job_name))
 
         scaled_job_json['metadata']['name'] = job_name
@@ -387,7 +393,6 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
                 done
         """]
 
-
     if update:
         try:
             group = "keda.sh"
@@ -412,8 +417,8 @@ def deploy_job(job_name: str, gpus: int, gpu_type: Optional[str], cpu: int, memo
         except Exception as e:
             print(f"Error while deploying job: {e}")
 
-def queue_job(job_name: str, job_id: str, job_payload: str, region: str = REGION):
-    dynamodb = boto3.resource('dynamodb', region_name=region)
+def queue_job(job_name: str, job_id: str, job_payload: str):
+    dynamodb = get_dynamodb_resource()
     table_name = f"{get_cluster_name()}-job-status"
     table = dynamodb.Table(table_name)
 
@@ -429,7 +434,7 @@ def queue_job(job_name: str, job_id: str, job_payload: str, region: str = REGION
     queur_url = get_job_queue_url_for_job(job_name)
     msg = {"job_id": job_id, "job_payload": job_payload}
     msg_str = json.dumps(msg)
-    queue_message(queur_url, msg_str, region=REGION)
+    queue_message(queur_url, msg_str)
     set_job_status(job_name, job_id, status="QUEUED")
     return True
 
@@ -463,7 +468,7 @@ def delete_all_job_resources(job_name: str):
 
 
 def delete_job_in_dynamo(job_name: str):
-    dynamodb = boto3.resource('dynamodb', region_name=REGION)
+    dynamodb = get_dynamodb_resource()
     table = dynamodb.Table(get_dynamodb_table_name())
      # Query items with the specific partition key
     response = table.query(
@@ -480,7 +485,7 @@ def delete_job_in_dynamo(job_name: str):
     click.echo(f"Job {job_name} deleted from DynamoDB.")
 
 def delete_dynamo_table():
-    dynamodb = boto3.resource('dynamodb', region_name=REGION)
+    dynamodb = get_dynamodb_resource()
     table_name = get_dynamodb_table_name()
     try:
         table = dynamodb.Table(table_name)
@@ -604,7 +609,7 @@ def queue_new_job(job_name: str, job_id: str, job_payload: str):
 
 
 def delete_queued_message(receipt_handle: str):
-    sqs = boto3.client('sqs', region_name=REGION)
+    sqs = get_sqs_client()
     queue_url = os.getenv('QUEUE_URL', None)
     if not queue_url:
         raise Exception("QUEUE_URL not set in environment variables.")
@@ -613,9 +618,9 @@ def delete_queued_message(receipt_handle: str):
     return response
 
 
-def create_table_for_job_status(region: str = REGION):
+def create_table_for_job_status():
     table_name = get_dynamodb_table_name()
-    dynamodb = boto3.resource('dynamodb', region_name=region)
+    dynamodb = get_dynamodb_resource()
     try:
         # Create the DynamoDB table
         table = dynamodb.create_table(TableName=table_name,
@@ -636,14 +641,14 @@ def create_table_for_job_status(region: str = REGION):
 
 # EXPOSE
 def set_job_status(job_name: str, job_id: str, status: str):
-    dynamodb = boto3.resource('dynamodb', region_name=REGION)
+    dynamodb = get_dynamodb_resource()
     table = dynamodb.Table(get_dynamodb_table_name())
     response = table.put_item(Item={'job_name': job_name, 'job_id': job_id, 'status': status})
     return response
 
 #EXPOSE
 def get_job_status(job_name: str, job_id: str):
-    dynamodb = boto3.resource('dynamodb', region_name=REGION)
+    dynamodb = get_dynamodb_resource()
     table = dynamodb.Table(get_dynamodb_table_name())
     response = table.get_item(Key={'job_name': job_name, 'job_id': job_id})
     return response['Item']['status'] if 'Item' in response else None
