@@ -1,20 +1,21 @@
 import os
 import subprocess
 import time
+import json
 from threading import Thread, Event
 from typing import List, Optional, Dict, Any
 
 import boto3
 import click
 import yaml
-from kubernetes import client, config, utils, watch
+from kubernetes import client, config, utils, watch, dynamic
 from kubernetes.client import ApiTypeError, ApiException
 from pkg_resources import resource_filename
 
-from tensorkube.constants import NAMESPACE, REGION, PodStatus, BUILD_TOOL, DEFAULT_NAMESPACE, TENSORFUSE_NAMESPACES, \
+from tensorkube.constants import NAMESPACE, PodStatus, BUILD_TOOL, DEFAULT_NAMESPACE, TENSORFUSE_NAMESPACES, \
     get_cluster_name, CliColors
-from tensorkube.services.aws_service import get_aws_account_id
-
+from tensorkube.services.aws_service import get_aws_account_id, get_eks_client, get_session_region, get_session_profile_name
+import os
 
 def get_s3_pv_name(env_name: Optional[str] = None):
     if env_name and env_name != DEFAULT_NAMESPACE:
@@ -112,7 +113,7 @@ def delete_aws_secret(namespace: str = DEFAULT_NAMESPACE, context_name: Optional
     v1.delete_namespaced_secret(name="aws-secret", namespace=namespace)
 
 
-def create_build_pv_and_pvc(bucket_name: str, region: str = REGION, env: Optional[str] = None,
+def create_build_pv_and_pvc(bucket_name: str, env: Optional[str] = None,
                             context_name: Optional[str] = None):
     if not context_name:
         context_name = get_tensorkube_cluster_context_name()
@@ -129,7 +130,7 @@ def create_build_pv_and_pvc(bucket_name: str, region: str = REGION, env: Optiona
 
     env_namespace = env if env else DEFAULT_NAMESPACE
 
-    pv['spec']['mountOptions'] = ["allow-delete", "region {}".format(region)]
+    pv['spec']['mountOptions'] = ["allow-delete", "region {}".format(get_session_region())]
     pv['spec']['csi']['volumeAttributes']['bucketName'] = bucket_name
     pv['metadata']['namespace'] = env_namespace
     pv['metadata']['name'] = get_s3_pv_name(env_name=env)
@@ -413,12 +414,13 @@ def set_stop_event_post_ksvc_ready(service_name, namespace, stop_event, context_
     k8s_api_client = config.new_client_from_config(context=context_name)
     custom_api = client.CustomObjectsApi(k8s_api_client)
     v1 = client.CoreV1Api(k8s_api_client)
+    revision_name = None
 
     group = "serving.knative.dev"
     version = "v1"
     plural = "services"
 
-    max_wait_seconds = 600  # maximum time to wait (adjust as needed)
+    max_wait_seconds = 1200  # maximum time to wait (adjust as needed)
     start_time = time.time()
 
     while not stop_event.is_set():
@@ -430,6 +432,8 @@ def set_stop_event_post_ksvc_ready(service_name, namespace, stop_event, context_
                 plural=plural,
                 name=service_name
             )
+            if ksvc['status']['latestCreatedRevisionName']:
+                revision_name = ksvc['status']['latestCreatedRevisionName']
             conditions = ksvc.get("status", {}).get("conditions", [])
             for condition in conditions:
                 if condition.get("type") == "Ready" and condition.get("status") == "True":
@@ -441,11 +445,21 @@ def set_stop_event_post_ksvc_ready(service_name, namespace, stop_event, context_
                 print(f"Service {service_name} not found in namespace {namespace}")
             else:
                 raise
+
+        # fallback to service name if no latest ready revision name is found
+        if not revision_name:
+            revision_name = service_name
+            pods = v1.list_namespaced_pod(
+                namespace=namespace,
+                label_selector=f'serving.knative.dev/service={service_name}'
+            )
+        else:
         # Check pods for CrashLoopBackOff status
-        pods = v1.list_namespaced_pod(
-            namespace=namespace,
-            label_selector=f'serving.knative.dev/service={service_name}'
-        )
+            pods = v1.list_namespaced_pod(
+                namespace=namespace,
+                label_selector=f'serving.knative.dev/revision={revision_name}'
+            )
+            
         for pod in pods.items:
             for cs in pod.status.container_statuses or []:
                 waiting_state = cs.state.waiting
@@ -778,6 +792,7 @@ def get_image_tags_to_retain(sanitised_project_name: str, service_name: str, nam
     return image_tags_to_retain
 
 
+
 def get_pod_name_corresponing_to_job(job_name: str, namespace: str = DEFAULT_NAMESPACE,
                                      context_name: Optional[str] = None, max_retries=5) -> Optional[str]:
     if not context_name:
@@ -1209,7 +1224,8 @@ def add_user_to_k8s(user_name):
 
 
 def generate_kubeconfig():
-    eks_client = boto3.client('eks', region_name=REGION, )
+    eks_client = get_eks_client()
+    
 
     cluster_name = get_cluster_name()
     # Retrieve cluster information
@@ -1218,19 +1234,48 @@ def generate_kubeconfig():
     # Extract cluster details
     endpoint = cluster_info['endpoint']
     cluster_ca_certificate = cluster_info['certificateAuthority']['data']
+    region = get_session_region()
+    profile = get_session_profile_name()
 
     # Create a kubeconfig dictionary
-    kubeconfig_data = {"apiVersion": "v1", "clusters": [
-        {"cluster": {"server": endpoint, "certificate-authority-data": cluster_ca_certificate},
-            "name": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}'}], "contexts": [{
-        "context": {"cluster": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}',
-            "user": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}'},
-        "name": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}'}],
-        "current-context": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}', "kind": "Config",
-        "users": [{"name": f'arn:aws:eks:us-east-1:{get_aws_account_id()}:cluster/{cluster_name}', "user": {
-            "exec": {"apiVersion": "client.authentication.k8s.io/v1beta1", "command": "aws",
-                "args": ["eks", "get-token", "--cluster-name", cluster_name],
-                "env": [{"name": "AWS_DEFAULT_REGION", "value": REGION}]}}}]}
+    kubeconfig_data = {
+        "apiVersion": "v1",
+        "clusters": [{
+            "cluster": {
+                "server": endpoint,
+                "certificate-authority-data": cluster_ca_certificate
+            },
+            "name": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}'
+        }],
+        "contexts": [{
+            "context": {
+                "cluster": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}',
+                "user": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}'
+            },
+            "name": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}'
+        }],
+        "current-context": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}',
+        "kind": "Config",
+        "users": [{
+            "name": f'arn:aws:eks:{region}:{get_aws_account_id()}:cluster/{cluster_name}',
+            "user": {
+                "exec": {
+                    "apiVersion": "client.authentication.k8s.io/v1beta1",
+                    "command": "aws",
+                    "args": [
+                        "eks",
+                        "get-token",
+                        "--profile",
+                        profile,
+                        "--cluster-name", cluster_name
+                    ],
+                    "env": [
+                        {"name": "AWS_DEFAULT_REGION", "value": get_session_region()}, #TODO: is this env needed ?
+                    ]
+                }
+            }
+        }]
+    }
     kubeconfig_dir = os.path.expanduser('~/.kube')
     kubeconfig_file = os.path.join(kubeconfig_dir, 'config')
 
@@ -1447,3 +1492,104 @@ def get_jobs_by_container_image(image: str, namespace: str = "keda") -> list:
         if e.status == 404:
             return []
         raise e
+
+
+def add_helm_annotations_and_labels(resource_api_version: str, resource_type: str, resource_name: str,
+                                    release_name: str, release_namespace: str,
+                                    resource_namespace: Optional[str] = DEFAULT_NAMESPACE,):
+
+
+    context_name = get_tensorkube_cluster_context_name()
+    if not context_name:
+        raise Exception("Unable to get cluster context")
+    k8s_api_client = config.new_client_from_config(context=context_name)
+    dyn_client = dynamic.DynamicClient(k8s_api_client)
+
+    # Locate the resource dynamically
+    resource = dyn_client.resources.get(api_version=resource_api_version, kind=resource_type)
+
+    # Fetch the existing object
+    try:
+        obj = resource.get(name=resource_name, namespace=resource_namespace) if resource_namespace else resource.get(name=resource_name)
+    except ApiException as e:
+        raise RuntimeError(f"Failed to fetch resource: {e}")
+
+    # Prepare annotations and labels
+    annotations = dict(obj.metadata.annotations) or {}
+    labels = dict(obj.metadata.labels or {})
+
+
+    annotations["meta.helm.sh/release-name"] = release_name
+    annotations["meta.helm.sh/release-namespace"] = release_namespace
+    labels["app.kubernetes.io/managed-by"] = "Helm"
+
+    patch_body = {
+        "metadata": {
+            "annotations": annotations,
+            "labels": labels
+        }
+    }
+
+    # Patch the resource
+    try:
+        if resource_namespace:
+            resource.patch(name=resource_name, namespace=resource_namespace, body=patch_body)
+        else:
+            resource.patch(name=resource_name, body=patch_body)
+        print(f"✅ {resource_type}/{resource_name} annotated and labeled for Helm.")
+    except ApiException as e:
+        raise RuntimeError(f"Failed to patch resource: {e}")
+
+
+def get_helm_release_version(release_name: str, namespace: str):
+    try:
+        result = subprocess.run(
+            ["helm", "get", "metadata", release_name, "-n", namespace, "-o", "json"],
+            check=True,
+            stdout=subprocess.PIPE
+        )
+        details = json.loads(result.stdout)
+        version = details.get("version", None)
+        if not version:
+            raise RuntimeError(f"Could not find version for release {release_name} in namespace {namespace}")
+        return version
+
+    except subprocess.CalledProcessError as e:
+        print("Error running helm list:", e)
+        return None
+
+
+def get_unhealthy_nodes(cluster_name: str):
+    context_name = get_tensorkube_cluster_context_name()
+    if not context_name:
+        raise Exception("Unable to get cluster context")
+    k8s_api_client = config.new_client_from_config(context=context_name)
+
+    # Load the existing kubeconfig
+    v1 = client.CoreV1Api(k8s_api_client)
+    try:
+        print(f"Getting unhealthy nodes for cluster: {cluster_name}")
+        nodes = v1.list_node()
+        unhealthy_nodes = []
+        current_nodes = []
+        for node in nodes.items:
+            # about condition - https://kubernetes.io/docs/reference/node/node-status/#condition
+            current_nodes.append(node.metadata.name)
+            if node.status.conditions:
+                for condition in node.status.conditions:
+                    # Check for 'Ready' condition and its status should not be 'True'. values are 'True', 'False', 'Unknown'
+                    # you should also check for the last heartbeat time to determine if the node is unhealthy
+                    if condition.type == 'Ready' and condition.status != 'True':
+                        # Check if the last heartbeat time is older than a certain threshold (e.g., 5 minutes)
+                        print(f"Node {node.metadata.name} is unhealthy")
+                        print(f"status: {condition.status}")
+                        print(f"last heartbeat time: {condition.last_heartbeat_time}")
+                        print(f"message: {condition.message}")
+                        print(f"reason: {condition.reason}")
+                        unhealthy_nodes.append(node.metadata.name)
+        print(f"Current nodes: {current_nodes}")
+        print(f"Unhealthy nodes: {unhealthy_nodes}")
+        return unhealthy_nodes
+    except Exception as e:
+        print(f"Failed to get nodes: {e}")
+        raise Exception(f"Failed to get nodes: {e}")
