@@ -1,4 +1,3 @@
-import pprint
 from typing import Optional, List, Dict
 
 import click
@@ -8,7 +7,6 @@ from rich.table import Table
 from rich.tree import Tree
 
 from tensorkube.constants import DEFAULT_NAMESPACE, DATASET_BUCKET_TYPE
-from tensorkube.services.aws_service import get_bucket_name
 from tensorkube.services.dataset_service import list_datasets
 from tensorkube.services.k8s_service import start_streaming_pod, ssh_into_pod, list_jobs, get_pods_for_jobs, \
     delete_job, ssh_into_pod_with_podman
@@ -16,6 +14,7 @@ from tensorkube.services.knative_service import list_deployed_services, get_knat
     get_pods_for_service, get_istio_ingress_gateway_hostname, delete_knative_service_by_name
 from tensorkube.services.tls_service import get_all_virtualservices, find_domains_for_service, is_custom_domain
 from tensorkube.services.train import get_training_id_from_job_name, get_training_stats
+from tensorkube.services.s3_service import get_bucket_name
 
 # Message Constants
 
@@ -24,6 +23,7 @@ DELETION_SECOND_CONFIRMATION_WITH_TYPING = "You have chosen to delete the deploy
 
 
 def list_tensorkube_deployments(env_name: Optional[str] = None, all: bool = False, old: bool = False):
+    # set up the initial table
     table = Table(title="Tensorkube Deployments")
     trees = []
     table.add_column("Name", style="magenta", no_wrap=True)
@@ -31,16 +31,21 @@ def list_tensorkube_deployments(env_name: Optional[str] = None, all: bool = Fals
     table.add_column("Ready", no_wrap=False, overflow="fold")
     table.add_column("Env", no_wrap=False, overflow="fold")
     table.add_column("Reason", no_wrap=False, overflow="fold")
-
+    # get the ingress gateway
     elb_url = get_istio_ingress_gateway_hostname()
 
+    # get the services either all or within a namespace
     deployed_services = list_deployed_services(env_name=env_name, all=all)
     if not deployed_services:
         return
     services = deployed_services['items']
-    namespaces = env_name if env_name else DEFAULT_NAMESPACE
-    virtual_services = get_all_virtualservices(namespace=namespaces)
+    if all:
+        namespaces = [service['metadata']['namespace'] for service in services]
+    else:
+        namespaces = [env_name if env_name else DEFAULT_NAMESPACE]
+    virtual_services = get_all_virtualservices(namespaces=namespaces)
     for service in services:
+        service_env = service["metadata"]["namespace"]
         ready_condition = get_ready_condition(service)
         service_name = service['metadata']['name']
         if 'latestReadyRevisionName' in service['status']:
@@ -50,12 +55,12 @@ def list_tensorkube_deployments(env_name: Optional[str] = None, all: bool = Fals
         if old:
             service_url = service['status']['url']
         else:
-            domains = find_domains_for_service(virtualservices=virtual_services,service_name=service_name)
-            custom_domains = list(filter(is_custom_domain, domains.domains))
+            domains = find_domains_for_service(virtualservices=virtual_services,service_name=service_name, namespace= service_env)
+            custom_domains = list(filter(lambda domain: is_custom_domain(domain, service_env), domains.domains))
             if custom_domains:
                 service_url = f'https://{custom_domains[0]}/'
             else:
-                service_url = f'http://{elb_url}/svc/{service["metadata"]["namespace"]}/{service["metadata"]["name"]}/'
+                service_url = f'http://{elb_url}/svc/{service_env}/{service["metadata"]["name"]}/'
         service_env = service['metadata']['namespace']
         tree = Tree("[bold][bright_magenta]" + service_name)
         tree.add("[bold]env:[/] " + service_env)
