@@ -1,13 +1,12 @@
-import boto3
-from tensorkube.constants import REGION, get_cluster_name
-
 
+from tensorkube.services.aws_service import get_sqs_client
+from tensorkube.constants import get_cluster_name
 def get_sqs_access_policy_name():
     return f"{get_cluster_name()}-sqs-access-policy"
 
 
-def create_sqs_queue(queue_name: str, region: str = REGION) -> str:
-    sqs = boto3.client('sqs', region_name=region)
+def create_sqs_queue(queue_name: str) -> str:
+    sqs = get_sqs_client()
     response = sqs.create_queue(
         QueueName=queue_name,
         Attributes={
@@ -20,14 +19,14 @@ def create_sqs_queue(queue_name: str, region: str = REGION) -> str:
     return queue_url
 
 
-def delete_sqs_queue(queue_name: str, region: str = REGION) -> None:
-    sqs = boto3.client('sqs', region_name=region)
+def delete_sqs_queue(queue_name: str) -> None:
+    sqs = get_sqs_client()
     queue_url = sqs.get_queue_url(QueueName=queue_name)['QueueUrl']
     sqs.delete_queue(QueueUrl=queue_url)
     print(f"Queue {queue_name} deleted successfully.")
 
-def queue_message(queue_url: str, message_body: str, region: str = REGION) -> None:
-    sqs = boto3.client('sqs', region_name=region)
+def queue_message(queue_url: str, message_body: str) -> None:
+    sqs = get_sqs_client()
     response = sqs.send_message(
         QueueUrl=queue_url,
         MessageBody=message_body
