@@ -7,7 +7,6 @@ import re
 from dataclasses import dataclass
 from typing import Optional, List, Dict
 
-import boto3
 import click
 from kubernetes import config, client
 from pkg_resources import resource_filename
@@ -24,29 +23,51 @@ from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name
 class ServiceDomains:
     service_name: str
     domains: List[str]
+    namespace: str
 
 
-def get_all_virtualservices(namespace: str = "default") -> List[Dict]:
-    """Fetch all VirtualServices once"""
+
+def get_all_virtualservices(namespaces: List[str]) -> List[Dict]:
+    """
+    Fetch all VirtualServices from a list of namespaces.
+
+    Args:
+        namespaces (List[str]): List of namespaces to query for VirtualServices.
+
+    Returns:
+        List[Dict]: A list of VirtualServices from all specified namespaces.
+    """
     try:
+        # Load Kubernetes configuration
         config.load_kube_config()
         k8s_client = client.CustomObjectsApi()
 
-        vs_list = k8s_client.list_namespaced_custom_object(
-            group="networking.istio.io",
-            version="v1",
-            namespace=namespace,
-            plural="virtualservices"
-        )
-        return vs_list.get('items', [])
+        # Initialize an empty list to store VirtualServices
+        virtualservices = []
+
+        # Fetch VirtualServices from each namespace
+        for namespace in namespaces:
+            vs_list = k8s_client.list_namespaced_custom_object(
+                group="networking.istio.io",
+                version="v1",
+                namespace=namespace,
+                plural="virtualservices"
+            )
+            virtualservices.extend(vs_list.get('items', []))
+
+        return virtualservices
+
     except Exception as e:
         raise Exception(f"Failed to fetch VirtualServices: {e}")
 
 
-def find_domains_for_service(virtualservices: List[Dict], service_name: str) -> ServiceDomains:
+def find_domains_for_service(virtualservices: List[Dict], service_name: str, namespace: str) -> ServiceDomains:
     """Process VirtualServices to find domains for a specific service"""
     domains = []
     for vs in virtualservices:
+        vs_namespace = vs.get('metadata', {}).get('namespace')
+        if vs_namespace != namespace:
+            continue  # Skip if it's not in the same namespace
         for http in vs['spec'].get('http', []):
             for route in http.get('route', []):
                 if route.get('destination', {}).get('host', '').startswith(service_name):
@@ -54,7 +75,9 @@ def find_domains_for_service(virtualservices: List[Dict], service_name: str) ->
 
     return ServiceDomains(
         service_name=service_name,
-        domains=list(set(domains))  # Remove duplicates
+        domains=list(set(domains)),
+        namespace=namespace,
+        # Remove duplicates
     )
 
 
@@ -240,6 +263,7 @@ def attach_domain_name(domain_name, force: bool = False):
             print("Attaching certificate to the cluster")
             configure_ssl_for_ingress_gateway(new_cert_arn)
 
-def is_custom_domain(domain: str) -> bool:
+def is_custom_domain(domain: str, service_env:str) -> bool:
     # Helper function to determine if a domain is custom/not generated by Knative or sslip.io
-    return not (domain.endswith('.sslip.io') or 'svc.cluster.local' in domain or 'default.svc' in domain or domain.endswith('.default'))
+    return not (domain.endswith('.sslip.io') or 'svc.cluster.local' in domain or 'default.svc' in domain or domain.endswith('.default')
+                or domain.endswith(f'.{service_env}') or domain.endswith(f'{service_env}.svc'))
