@@ -2,8 +2,6 @@ import json
 import logging
 import time
 from typing import Optional, List
-
-import boto3
 import click
 import yaml
 from kubernetes import config, utils
@@ -12,25 +10,25 @@ from pkg_resources import resource_filename
 
 from tensorkube.constants import DEFAULT_NAMESPACE, get_cluster_name, DATASET_BUCKET_TYPE
 from tensorkube.helpers import sanitise_name
-from tensorkube.services.aws_service import get_bucket_name
+from tensorkube.services.aws_service import get_logs_client
 from tensorkube.services.deploy import DEFAULT_CPU, DEFAULT_MEMORY
 from tensorkube.services.job_queue_service import deploy_job, queue_job, is_existing_queued_job
 from tensorkube.services.k8s_service import get_tensorkube_cluster_context_name, create_configmap, generate_kubeconfig
 from tensorkube.services.knative_service import get_instance_family_from_gpu_type
 from tensorkube.services.s3_access_service import get_s3_service_account_name
-from tensorkube.services.s3_service import create_s3_bucket
+from tensorkube.services.s3_service import create_s3_bucket, get_bucket_name
 
 # disable botocore info logs
 logging.getLogger('botocore').setLevel(logging.CRITICAL)
 
 AXOLOTL_IMAGE_TRAIN_JOB = "gane5h/build_tool:axo"
-AXOLOTL_IMAGE_SCALED_JOB = "tensorfuse/axolotl-train:v0.0.5"
+AXOLOTL_IMAGE_SCALED_JOB = "tensorfuse/axolotl-train:v0.0.10"
 
 
 def get_training_stats(job_name: str, start_time: int, namespace: str = "default"):
     log_group = f"/aws/containerinsights/{get_cluster_name()}/application"
     log_stream_prefix = job_name
-    client = boto3.client('logs')
+    client = get_logs_client()
     # Define the log query pattern to search for
     log_pattern = 'loss'
     end_time = int(time.time())
@@ -193,7 +191,7 @@ def axolotl_train(env: str, secrets: list, gpus: int, gpu_type: str, job_id: str
 
 
 # from hugging face model path
-supported_base_models = ['meta-llama/Llama-3.1-70B-Instruct', 'meta-llama/Llama-3.1-8B-Instruct']
+supported_base_models = ['meta-llama/Llama-3.1-70B-Instruct', 'meta-llama/Llama-3.1-8B-Instruct', 'google/gemma-3-27b-it']
 
 
 def get_dataset_config_for_base_model(base_model: str, s3_path: str) -> dict:
@@ -244,6 +242,8 @@ def get_axolotl_base_config_by_model(base_model: str) -> dict:
         fileName = resource_filename('tensorkube', 'configurations/axolotl_configs/llama-3.1-70B-Instruct.yaml')
     elif base_model == 'meta-llama/Llama-3.1-8B-Instruct':
         fileName = resource_filename('tensorkube', 'configurations/axolotl_configs/llama-3.1-8B-Instruct.yaml')
+    elif base_model == 'google/gemma-3-27b-it':
+        fileName = resource_filename('tensorkube', f'configurations/axolotl_configs/gemma-3-27b-it.yaml')
     else:
         raise Exception(f"Invalid base model {base_model}")
     with open(fileName, 'r') as f:
@@ -256,7 +256,7 @@ def create_fine_tuning_job(job_name: str, job_id: str, gpus: int, gpu_type: str,
                            secrets: List[str] = [], micro_batch_size: Optional[int] = None,
                            learning_rate: Optional[float] = None, lora_r: Optional[int] = None,
                            val_set_size: Optional[float] = None,
-                           wandb_entity: Optional[str] = None, hf_org_id: Optional[str] = None):
+                           wandb_entity: Optional[str] = None, hf_org_id: Optional[str] = None, store_weights_as_bf16: bool= False, **kwargs) -> None:
     # create the job definition
     env = 'keda'
     # validate the base model
@@ -284,7 +284,9 @@ def create_fine_tuning_job(job_name: str, job_id: str, gpus: int, gpu_type: str,
                                         wandb_name=job_id,
                                         base_config=base_yaml_dict,
                                         hf_org_id=hf_org_id)
+    config['store_weights_as_bf16'] = store_weights_as_bf16
     yaml_dict = {**base_yaml_dict, **config}
+    yaml_dict = {**yaml_dict, **kwargs}
     payload = json.dumps(yaml_dict)
     queue_job(job_name, job_id, payload)
     return
